adminAppliedUpdates method

Future<List<DbUpdate>> adminAppliedUpdates(
  1. String region
)

Lists the Database schema updates already installed

Summary:Lists the Database schema updates already installed.
This can only be used by users in the Flex Superuser role.
Return Type: DbUpdate

Parameters:

  • String region (required): The data center region the data resides in

Implementation

Future<List<DbUpdate>> adminAppliedUpdates(String region,) async {
  final response = await adminAppliedUpdatesWithHttpInfo(region,);
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body != null && response.statusCode != HttpStatus.noContent) {
    final responseBody = await _decodeBodyBytes(response);
    return (await apiClient.deserializeAsync(responseBody, 'List<DbUpdate>') as List)
      .cast<DbUpdate>()
      .toList(growable: false);

  }
  return Future<List<DbUpdate>>.value();
}