adminGetIsCurrent method
Returns a flag indicating if the database schema requires an upgrade
Summary:Returns a flag indicating if the database schema requires an upgrade.
This service can be used by any client. SuperUser role is not required.
Return Type: boolean
Parameters:
- String region (required): The data center region the data resides in
Implementation
Future<bool> adminGetIsCurrent(String region,) async {
final response = await adminGetIsCurrentWithHttpInfo(region,);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body != null && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'bool',) as bool;
}
return Future<bool>.value();
}