adminGetIsCurrentWithHttpInfo method

Future<Response> adminGetIsCurrentWithHttpInfo(
  1. String region
)

Returns a flag indicating if the database schema requires an upgrade

Summary:Returns a flag indicating if the database schema requires an upgrade.
This service can be used by any client. SuperUser role is not required.
Return Type: boolean

Note: This method returns the HTTP Response.

Parameters:

  • String region (required): The data center region the data resides in

Implementation

Future<Response> adminGetIsCurrentWithHttpInfo(String region,) async {
  // Verify required params are set.
  if (region == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: region');
  }

  // ignore: prefer_const_declarations
  final path = r'/{region}/aim/2.0/admin/schema/IsCurrent'
    .replaceAll('{region}', region);

  // ignore: prefer_final_locals
  Object postBody;

  final queryParams = <QueryParam>[];
  final headerParams = <String, String>{};
  final formParams = <String, String>{};

  const authNames = <String>['oauth2'];
  const contentTypes = <String>[];


  return apiClient.invokeAPI(
    path,
    'GET',
    queryParams,
    postBody,
    headerParams,
    formParams,
    contentTypes.isEmpty ? null : contentTypes[0],
    authNames,
  );
}