ApplicationsApi class

Constructors

ApplicationsApi([ApiClient apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applicationsGetByTenantid(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<ODataListResponseOfApplication>
Returns the EntitySet Applications
applicationsGetByTenantidWithHttpInfo(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<Response>
Returns the EntitySet Applications
applicationsGetSingleByApplicationidAndTenantid(int applicationId, String tenantId, String region, {String dollarExpand, String dollarSelect}) Future<Application>
Returns the entity with the key from Applications
applicationsGetSingleByApplicationidAndTenantidWithHttpInfo(int applicationId, String tenantId, String region, {String dollarExpand, String dollarSelect}) Future<Response>
Returns the entity with the key from Applications
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited