AssemblyDiagnostics class

Constructors

AssemblyDiagnostics({String name, String processor, String assemblyVersion, String fileVersion, String productVersion, String company, String copyright, int size, DateTime lastModified, DateTime dateCreated})
Returns a new AssemblyDiagnostics instance.

Properties

assemblyVersion String
getter/setter pair
company String
getter/setter pair
getter/setter pair
dateCreated DateTime
getter/setter pair
fileVersion String
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
lastModified DateTime
getter/setter pair
name String
getter/setter pair
processor String
getter/setter pair
productVersion String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AssemblyDiagnostics
Returns a new AssemblyDiagnostics instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<AssemblyDiagnostics>
mapFromJson(dynamic json) Map<String, AssemblyDiagnostics>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<AssemblyDiagnostics>>