Asset class

Constructors

Asset({int assetId, String tenantGuid, String name, List<Object> models = const [], List<Object> segments = const [], List<Role> roles = const [], UserPermissions permissions, DateTime dateCreated, DateTime dateModified, AssetStateEnum state})
Returns a new Asset instance.

Properties

assetId int
getter/setter pair
dateCreated DateTime
getter/setter pair
dateModified DateTime
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
models List<Object>
getter/setter pair
name String
getter/setter pair
permissions UserPermissions
getter/setter pair
roles List<Role>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<Object>
getter/setter pair
state AssetStateEnum
getter/setter pair
tenantGuid String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Asset
Returns a new Asset instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<Asset>
mapFromJson(dynamic json) Map<String, Asset>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<Asset>>