AssetsApi class

Constructors

AssetsApi([ApiClient apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

assetsAssignByTenantidAndAssetid(String tenantId, int assetId, String region, InlineObject parameters) Future<void>
Assigns a user to the given role on the asset
assetsAssignByTenantidAndAssetidWithHttpInfo(String tenantId, int assetId, String region, InlineObject parameters) Future<Response>
Assigns a user to the given role on the asset
assetsDeleteByAssetidAndTenantid(int assetId, String tenantId, String region, {String ifMatch}) Future<void>
Archive an Asset and and models for future deletion
assetsDeleteByAssetidAndTenantidWithHttpInfo(int assetId, String tenantId, String region, {String ifMatch}) Future<Response>
Archive an Asset and and models for future deletion
assetsGetByTenantid(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<ODataListResponseOfAsset>
Returns the EntitySet Assets
assetsGetByTenantidWithHttpInfo(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<Response>
Returns the EntitySet Assets
assetsGetSingleByAssetidAndTenantid(int assetId, String tenantId, String region, {String dollarExpand, String dollarSelect}) Future<Asset>
Returns the entity with the key from Assets
assetsGetSingleByAssetidAndTenantidWithHttpInfo(int assetId, String tenantId, String region, {String dollarExpand, String dollarSelect}) Future<Response>
Returns the entity with the key from Assets
assetsMemberAccessByAssetidAndTenantid(int assetId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<ODataListResponseOfMemberPermission>
Gets the list of users with access to this item and their permissions
assetsMemberAccessByAssetidAndTenantidWithHttpInfo(int assetId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<Response>
Gets the list of users with access to this item and their permissions
assetsPatchByAssetidAndTenantid(int assetId, String tenantId, String region, AssetEdit asset) Future<Asset>
Edit an existing asset
assetsPatchByAssetidAndTenantidWithHttpInfo(int assetId, String tenantId, String region, AssetEdit asset) Future<Response>
Edit an existing asset
assetsPermissionsByAssetidAndTenantid(int assetId, String tenantId, String region, {String dollarExpand, String dollarSelect}) Future<UserPermissions>
Gets the effective permissions for this current user
assetsPermissionsByAssetidAndTenantidWithHttpInfo(int assetId, String tenantId, String region, {String dollarExpand, String dollarSelect}) Future<Response>
Gets the effective permissions for this current user
assetsPostByTenantid(String tenantId, String region, AssetCreate asset) Future<Asset>
Post a new entity to EntitySet Assets
assetsPostByTenantidWithHttpInfo(String tenantId, String region, AssetCreate asset) Future<Response>
Post a new entity to EntitySet Assets
assetsRevokeByTenantidAndAssetid(String tenantId, int assetId, String region, InlineObject1 parameters) Future<void>
Revokes a user from the given role on the asset
assetsRevokeByTenantidAndAssetidWithHttpInfo(String tenantId, int assetId, String region, InlineObject1 parameters) Future<Response>
Revokes a user from the given role on the asset
assetsRolesByAssetidAndTenantid(int assetId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<ODataListResponseOfRole>
Gets the roles for the given Asset
assetsRolesByAssetidAndTenantidWithHttpInfo(int assetId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<Response>
Gets the roles for the given Asset
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited