AttributeDefinition class

Constructors

AttributeDefinition({String fullName, String groupName, AttributeDefinitionGroupTypeEnum groupType, String name, String canonicalName, bool imported, String semanticType, String unit, AttributeDefinitionDataTypeEnum dataType, DateTime dateCreated, DateTime dateModified})
Returns a new AttributeDefinition instance.

Properties

canonicalName String
getter/setter pair
dataType AttributeDefinitionDataTypeEnum
getter/setter pair
dateCreated DateTime
getter/setter pair
dateModified DateTime
getter/setter pair
fullName String
getter/setter pair
groupName String
getter/setter pair
groupType AttributeDefinitionGroupTypeEnum
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
imported bool
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticType String
getter/setter pair
unit String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AttributeDefinition
Returns a new AttributeDefinition instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<AttributeDefinition>
mapFromJson(dynamic json) Map<String, AttributeDefinition>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<AttributeDefinition>>