AttributeDefinitionCreate class

Constructors

AttributeDefinitionCreate({@required int assetModelId, @required String name, @required String groupName, AttributeDefinitionCreateGroupTypeEnum groupType, @required AttributeDefinitionCreateDataTypeEnum dataType, String semanticType, String unit})
Returns a new AttributeDefinitionCreate instance.

Properties

assetModelId int
getter/setter pair
dataType AttributeDefinitionCreateDataTypeEnum
getter/setter pair
groupName String
getter/setter pair
groupType AttributeDefinitionCreateGroupTypeEnum
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticType String
getter/setter pair
unit String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AttributeDefinitionCreate
Returns a new AttributeDefinitionCreate instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<AttributeDefinitionCreate>
mapFromJson(dynamic json) Map<String, AttributeDefinitionCreate>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<AttributeDefinitionCreate>>