AttributeDefinitionEntity class

Constructors

AttributeDefinitionEntity({String fullName, int assetModelId, int attributeDefinitionId, Model model, List<AttributeValueEntity> values = const [], String groupName, AttributeDefinitionEntityGroupTypeEnum groupType, String name, String canonicalName, bool imported, String semanticType, String unit, AttributeDefinitionEntityDataTypeEnum dataType, DateTime dateCreated, DateTime dateModified})
Returns a new AttributeDefinitionEntity instance.

Properties

assetModelId int
getter/setter pair
attributeDefinitionId int
getter/setter pair
canonicalName String
getter/setter pair
dataType AttributeDefinitionEntityDataTypeEnum
getter/setter pair
dateCreated DateTime
getter/setter pair
dateModified DateTime
getter/setter pair
fullName String
getter/setter pair
groupName String
getter/setter pair
groupType AttributeDefinitionEntityGroupTypeEnum
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
imported bool
getter/setter pair
model Model
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticType String
getter/setter pair
unit String
getter/setter pair
values List<AttributeValueEntity>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AttributeDefinitionEntity
Returns a new AttributeDefinitionEntity instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<AttributeDefinitionEntity>
mapFromJson(dynamic json) Map<String, AttributeDefinitionEntity>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<AttributeDefinitionEntity>>