AttributeValueEntity class

Constructors

AttributeValueEntity({int definitionId, int assetModelId, int entityId, ValueContainer value, DateTime dateCreated, DateTime dateModified, EntityBase entity})
Returns a new AttributeValueEntity instance.

Properties

assetModelId int
getter/setter pair
dateCreated DateTime
getter/setter pair
dateModified DateTime
getter/setter pair
definitionId int
getter/setter pair
entity EntityBase
getter/setter pair
entityId int
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ValueContainer
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AttributeValueEntity
Returns a new AttributeValueEntity instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<AttributeValueEntity>
mapFromJson(dynamic json) Map<String, AttributeValueEntity>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<AttributeValueEntity>>