AttributesApi class

Constructors

AttributesApi([ApiClient apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

attributesChangeDataTypeByAssetmodelidAndDefinitionidAndTenantid(int assetModelId, int definitionId, String dataType, String tenantId, String region) Future<ODataResponseOfBoolean>
Change the underlying data type for the attribute, migrating any existing data where possible
attributesChangeDataTypeByAssetmodelidAndDefinitionidAndTenantidWithHttpInfo(int assetModelId, int definitionId, String dataType, String tenantId, String region) Future<Response>
Change the underlying data type for the attribute, migrating any existing data where possible
attributesGetByAssetmodelidAndDefinitionidAndTenantid(int assetModelId, int definitionId, String tenantId, String region, {String dollarExpand, String dollarSelect}) Future<AttributeDefinitionEntity>
Operation to interrogate a single attribute definition
attributesGetByAssetmodelidAndDefinitionidAndTenantidWithHttpInfo(int assetModelId, int definitionId, String tenantId, String region, {String dollarExpand, String dollarSelect}) Future<Response>
Operation to interrogate a single attribute definition
attributesGetByTenantid(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<ODataListResponseOfAttributeDefinitionEntity>
Returns the EntitySet Attributes
attributesGetByTenantidWithHttpInfo(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<Response>
Returns the EntitySet Attributes
attributesGetModelValuesByAssetmodelidAndDefinitionidAndTenantid(int assetModelId, int definitionId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<ODataListResponseOfComplexValueBase>
Gets a sample of the attribute values for the definition
attributesGetModelValuesByAssetmodelidAndDefinitionidAndTenantidWithHttpInfo(int assetModelId, int definitionId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<Response>
Gets a sample of the attribute values for the definition
attributesGetValuesForEntityByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<ODataListResponseOfAttributeValue>
Gets the unimported attribute values for an entity from the source model
attributesGetValuesForEntityByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<Response>
Gets the unimported attribute values for an entity from the source model
attributesImportByAssetmodelidAndDefinitionidAndTenantid(int assetModelId, int definitionId, String tenantId, String region) Future<ODataResponseOfBoolean>
Imports attribute values from the source model file
attributesImportByAssetmodelidAndDefinitionidAndTenantidWithHttpInfo(int assetModelId, int definitionId, String tenantId, String region) Future<Response>
Imports attribute values from the source model file
attributesPatchByAssetmodelidAndDefinitionidAndTenantid(int assetModelId, int definitionId, String tenantId, String region, AttributeDefinitionEdit patch_) Future<AttributeDefinitionEntity>
Update an AttributeDefinition for a model
attributesPatchByAssetmodelidAndDefinitionidAndTenantidWithHttpInfo(int assetModelId, int definitionId, String tenantId, String region, AttributeDefinitionEdit patch_) Future<Response>
Update an AttributeDefinition for a model
attributesPostByTenantid(String tenantId, String region, AttributeDefinitionCreate attributeDefinitionEntity) Future<AttributeDefinitionEntity>
Creates a new AttributeDefinition for a model
attributesPostByTenantidWithHttpInfo(String tenantId, String region, AttributeDefinitionCreate attributeDefinitionEntity) Future<Response>
Creates a new AttributeDefinition for a model
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited