attributesGetByAssetmodelidAndDefinitionidAndTenantid method
Operation to interrogate a single attribute definition
Summary:Operation to interrogate a single attribute definition.
This service returns a single attribute definition for the provided keys, or responds with a not found (404).
Return Type: AttributeDefinitionEntity
Parameters:
-
int assetModelId (required): The model Id
-
int definitionId (required): The attribute definition ID
-
String tenantId (required): The unique Tenant ID (UUID or Identifier string)
-
String region (required): The data center region the data resides in
-
String dollarExpand: Expands related entities inline.
-
String dollarSelect: Selects which properties to include in the response.
Implementation
Future<AttributeDefinitionEntity> attributesGetByAssetmodelidAndDefinitionidAndTenantid(int assetModelId, int definitionId, String tenantId, String region, { String dollarExpand, String dollarSelect, }) async {
final response = await attributesGetByAssetmodelidAndDefinitionidAndTenantidWithHttpInfo(assetModelId, definitionId, tenantId, region, dollarExpand: dollarExpand, dollarSelect: dollarSelect, );
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body != null && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'AttributeDefinitionEntity',) as AttributeDefinitionEntity;
}
return Future<AttributeDefinitionEntity>.value();
}