attributesGetByAssetmodelidAndDefinitionidAndTenantidWithHttpInfo method
Operation to interrogate a single attribute definition
Summary:Operation to interrogate a single attribute definition.
This service returns a single attribute definition for the provided keys, or responds with a not found (404).
Return Type: AttributeDefinitionEntity
Note: This method returns the HTTP Response.
Parameters:
-
int assetModelId (required): The model Id
-
int definitionId (required): The attribute definition ID
-
String tenantId (required): The unique Tenant ID (UUID or Identifier string)
-
String region (required): The data center region the data resides in
-
String dollarExpand: Expands related entities inline.
-
String dollarSelect: Selects which properties to include in the response.
Implementation
Future<Response> attributesGetByAssetmodelidAndDefinitionidAndTenantidWithHttpInfo(int assetModelId, int definitionId, String tenantId, String region, { String dollarExpand, String dollarSelect, }) async {
// Verify required params are set.
if (assetModelId == null) {
throw ApiException(HttpStatus.badRequest, 'Missing required param: assetModelId');
}
if (definitionId == null) {
throw ApiException(HttpStatus.badRequest, 'Missing required param: definitionId');
}
if (tenantId == null) {
throw ApiException(HttpStatus.badRequest, 'Missing required param: tenantId');
}
if (region == null) {
throw ApiException(HttpStatus.badRequest, 'Missing required param: region');
}
// ignore: prefer_const_declarations
final path = r'/{region}/aim/2.0/{tenantId}/Attributes(AssetModelId={assetModelId},AttributeDefinitionId={definitionId})'
.replaceAll('{assetModelId}', assetModelId.toString())
.replaceAll('{definitionId}', definitionId.toString())
.replaceAll('{tenantId}', tenantId)
.replaceAll('{region}', region);
// ignore: prefer_final_locals
Object postBody;
final queryParams = <QueryParam>[];
final headerParams = <String, String>{};
final formParams = <String, String>{};
if (dollarExpand != null) {
queryParams.addAll(_convertParametersForCollectionFormat('', '\$expand', dollarExpand));
}
if (dollarSelect != null) {
queryParams.addAll(_convertParametersForCollectionFormat('', '\$select', dollarSelect));
}
const authNames = <String>['oauth2'];
const contentTypes = <String>[];
return apiClient.invokeAPI(
path,
'GET',
queryParams,
postBody,
headerParams,
formParams,
contentTypes.isEmpty ? null : contentTypes[0],
authNames,
);
}