Cell class

Constructors

Cell({int definition, String name, ValueContainer value})
Returns a new Cell instance.

Properties

definition int
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ValueContainer
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Cell
Returns a new Cell instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<Cell>
mapFromJson(dynamic json) Map<String, Cell>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<Cell>>