ComponentCreate class

Constructors

ComponentCreate({int componentTypeId, @required int assetModelId, int entityId, String externalIdentifier, String name, String description, String externalObjectType})
Returns a new ComponentCreate instance.

Properties

assetModelId int
The identifier of the Model this entity belongs to
getter/setter pair
componentTypeId int
getter/setter pair
description String
Optional Description of the document
getter/setter pair
entityId int
Gets or sets the entity identifier / Label.
getter/setter pair
externalIdentifier String
The immutable unique identifier key for this Entity
getter/setter pair
externalObjectType String
A system identifier of the type of entity
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
name String
The name of the entity
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ComponentCreate
Returns a new ComponentCreate instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<ComponentCreate>
mapFromJson(dynamic json) Map<String, ComponentCreate>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<ComponentCreate>>