ComponentTypeInfo class
Constructors
Properties
- assetModelId ↔ int
-
getter/setter pair
- dateCreated ↔ DateTime
-
getter/setter pair
- dateModified ↔ DateTime
-
getter/setter pair
- description ↔ String
-
getter/setter pair
- entityId ↔ int
-
getter/setter pair
- externalIdentifier ↔ String
-
getter/setter pair
- externalObjectName ↔ String
-
getter/setter pair
- externalObjectType ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- model ↔ ModelInfo
-
getter/setter pair
- modelName ↔ String
-
getter/setter pair
- name ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → ComponentTypeInfo -
Returns a new ComponentTypeInfo instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< ComponentTypeInfo> -
mapFromJson(
dynamic json) → Map< String, ComponentTypeInfo> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< ComponentTypeInfo> >