componentsContainingSpacesByAssetmodelidAndEntityidAndTenantid method

Future<ODataListResponseOfSpace> componentsContainingSpacesByAssetmodelidAndEntityidAndTenantid(
  1. int assetModelId,
  2. int entityId,
  3. String tenantId,
  4. String region, {
  5. String dollarExpand,
  6. String dollarFilter,
  7. String dollarSelect,
  8. String dollarOrderby,
  9. int dollarTop,
  10. int dollarSkip,
  11. bool dollarCount,
  12. double tolerance,
  13. bool inSameAsset,
})

Gets the Spaces this Component is placed in, based on Footprint data

Summary:Gets the Spaces this Component is placed in, based on Footprint data.
Returns the Spaces where the component is wholly contained in the volume
This is a derived value based on the component geometry being wholly within the spatial footprint, and wholly within the Z-axis range of the space.
A 'tolerance' can be provided to extend or reduce the buffer included at the boundaries of the component
.
Return Type: ODataListResponseOfSpace
For more information about OData responses link.

Parameters:

  • int assetModelId (required): The assetModel ID of the Component

  • int entityId (required): The ID of the Component entity

  • String tenantId (required): The unique Tenant ID (UUID or Identifier string)

  • String region (required): The data center region the data resides in

  • String dollarExpand: Expands related entities inline.

  • String dollarFilter: Filters the results, based on a Boolean condition.

  • String dollarSelect: Selects which properties to include in the response.

  • String dollarOrderby: Sorts the results.

  • int dollarTop: Returns only the first n results.

  • int dollarSkip: Skips the first n results.

  • bool dollarCount: Includes a count of the matching results in the response.

  • double tolerance: Tolerance in millimeters. Can be negative. Default: 10mm

  • bool inSameAsset: Limit the results to spaces in the same Asset

Implementation

Future<ODataListResponseOfSpace> componentsContainingSpacesByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, { String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount, double tolerance, bool inSameAsset, }) async {
  final response = await componentsContainingSpacesByAssetmodelidAndEntityidAndTenantidWithHttpInfo(assetModelId, entityId, tenantId, region,  dollarExpand: dollarExpand, dollarFilter: dollarFilter, dollarSelect: dollarSelect, dollarOrderby: dollarOrderby, dollarTop: dollarTop, dollarSkip: dollarSkip, dollarCount: dollarCount, tolerance: tolerance, inSameAsset: inSameAsset, );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body != null && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'ODataListResponseOfSpace',) as ODataListResponseOfSpace;

  }
  return Future<ODataListResponseOfSpace>.value();
}