ContactEntity class

Constructors

ContactEntity({int contactId, int entityAssetModelId, int entityId, DateTime dateCreated, DateTime dateModified, ContactEntityRoleEnum role, String entityExternalIdentifier, String entityName, String entityDescription, RelatedEntity entity})
Returns a new ContactEntity instance.

Properties

contactId int
getter/setter pair
dateCreated DateTime
getter/setter pair
dateModified DateTime
getter/setter pair
entity RelatedEntity
getter/setter pair
entityAssetModelId int
getter/setter pair
entityDescription String
getter/setter pair
entityExternalIdentifier String
getter/setter pair
entityId int
getter/setter pair
entityName String
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
role ContactEntityRoleEnum
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ContactEntity
Returns a new ContactEntity instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<ContactEntity>
mapFromJson(dynamic json) Map<String, ContactEntity>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<ContactEntity>>