DocumentCreate class
Constructors
DocumentCreate ({String url , String location , String itemReference , String scope , String revision , String purpose , String intendedUse , @required int assetModelId , int entityId , String externalIdentifier , String name , String description , String externalObjectType })
Returns a new DocumentCreate instance.
Properties
assetModelId
↔ int
The identifier of the Model this entity belongs to
getter/setter pair
description
↔ String
Optional Description of the document
getter/setter pair
entityId
↔ int
Gets or sets the entity identifier / Label.
getter/setter pair
externalIdentifier
↔ String
The immutable unique identifier key for this Entity
getter/setter pair
externalObjectType
↔ String
A system identifier of the type of entity
getter/setter pair
hashCode
→ int
The hash code for this object.
no setter override
intendedUse
↔ String
Intended Use for this document.
getter/setter pair
itemReference
↔ String
Identifier for the referenced item in the external source (classification, document or library) For documents hosted in Flex this should be the fileId
getter/setter pair
location
↔ String
Location, where the external source (classification, document or library). For externally hosted documents normally given as an URL location string. For documents hosted in Flex, use the value 'Flex', and provide the Flex 'fileId' in the Item Reference
getter/setter pair
name
↔ String
The name of the entity
getter/setter pair
purpose
↔ String
Purpose for this document.
getter/setter pair
revision
↔ String
Document revision designation
getter/setter pair
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
scope
↔ String
Scope for this document.
getter/setter pair
url
↔ String
The Url of the document. Prefer Location over setting the URL
getter/setter pair