itemReference property

String itemReference
getter/setter pair

Identifier for the referenced item in the external source (classification, document or library) For documents hosted in Flex this should be the fileId

Implementation

String itemReference;