DocumentEdit class

Constructors

DocumentEdit({String url, String location, String itemReference, String scope, String revision, String purpose, String intendedUse, String name, String description, String externalObjectType})
Returns a new DocumentEdit instance.

Properties

description String
Optional Description of the document
getter/setter pair
externalObjectType String
A system identifier of the type of entity
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
intendedUse String
Intended Use for this document.
getter/setter pair
itemReference String
Identifier for the referenced item in the external source (classification, document or library) For documents hosted in Flex this should be the fileId
getter/setter pair
location String
Location, where the external source (classification, document or library). For externally hosted documents normally given as an URL location string. For documents hosted in Flex, use the value 'Flex', and provide the Flex 'fileId' in the Item Reference
getter/setter pair
name String
The name of the entity
getter/setter pair
purpose String
Purpose for this document.
getter/setter pair
revision String
Document revision designation
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String
Scope for this document.
getter/setter pair
url String
The Url of the document. Prefer Location over setting the URL
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) DocumentEdit
Returns a new DocumentEdit instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<DocumentEdit>
mapFromJson(dynamic json) Map<String, DocumentEdit>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<DocumentEdit>>