location property
Location, where the external source (classification, document or library). For externally hosted documents normally given as an URL location string. For documents hosted in Flex, use the value 'Flex', and provide the Flex 'fileId' in the Item Reference
Implementation
String location;