entitiesAsOfByKindWithHttpInfo method

Future<Response> entitiesAsOfByKindWithHttpInfo(
  1. DateTime date,
  2. String entityKind,
  3. String tenantId,
  4. String region, {
  5. String dollarExpand,
  6. String dollarFilter,
  7. String dollarSelect,
  8. String dollarOrderby,
  9. int dollarTop,
  10. int dollarSkip,
  11. bool dollarCount,
})

Query a set of Entities at a point in time

Summary:Query a set of Entities at a point in time.
Service allows consumers to interogate the state of entities at any point in the history by specifying a date to view the results at
Note that casting is not currently supported..
Return Type: ODataListResponseOfEntity
For more information about OData responses link.

Note: This method returns the HTTP Response.

Parameters:

  • DateTime date (required): The Date to view the entites at

  • String entityKind (required): The kind of entity to return

  • String tenantId (required): The unique Tenant ID (UUID or Identifier string)

  • String region (required): The data center region the data resides in

  • String dollarExpand: Expands related entities inline.

  • String dollarFilter: Filters the results, based on a Boolean condition.

  • String dollarSelect: Selects which properties to include in the response.

  • String dollarOrderby: Sorts the results.

  • int dollarTop: Returns only the first n results.

  • int dollarSkip: Skips the first n results.

  • bool dollarCount: Includes a count of the matching results in the response.

Implementation

Future<Response> entitiesAsOfByKindWithHttpInfo(DateTime date, String entityKind, String tenantId, String region, { String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount, }) async {
  // Verify required params are set.
  if (date == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: date');
  }
  if (entityKind == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: entityKind');
  }
  if (tenantId == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: tenantId');
  }
  if (region == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: region');
  }

  // ignore: prefer_const_declarations
  final path = r'/{region}/aim/2.0/{tenantId}/Entities/AsOf(date={date},entityKind={entityKind})'
    .replaceAll('{date}', date.toString())
    .replaceAll('{entityKind}', entityKind)
    .replaceAll('{tenantId}', tenantId)
    .replaceAll('{region}', region);

  // ignore: prefer_final_locals
  Object postBody;

  final queryParams = <QueryParam>[];
  final headerParams = <String, String>{};
  final formParams = <String, String>{};

  if (dollarExpand != null) {
    queryParams.addAll(_convertParametersForCollectionFormat('', '\$expand', dollarExpand));
  }
  if (dollarFilter != null) {
    queryParams.addAll(_convertParametersForCollectionFormat('', '\$filter', dollarFilter));
  }
  if (dollarSelect != null) {
    queryParams.addAll(_convertParametersForCollectionFormat('', '\$select', dollarSelect));
  }
  if (dollarOrderby != null) {
    queryParams.addAll(_convertParametersForCollectionFormat('', '\$orderby', dollarOrderby));
  }
  if (dollarTop != null) {
    queryParams.addAll(_convertParametersForCollectionFormat('', '\$top', dollarTop));
  }
  if (dollarSkip != null) {
    queryParams.addAll(_convertParametersForCollectionFormat('', '\$skip', dollarSkip));
  }
  if (dollarCount != null) {
    queryParams.addAll(_convertParametersForCollectionFormat('', '\$count', dollarCount));
  }

  const authNames = <String>['oauth2'];
  const contentTypes = <String>[];


  return apiClient.invokeAPI(
    path,
    'GET',
    queryParams,
    postBody,
    headerParams,
    formParams,
    contentTypes.isEmpty ? null : contentTypes[0],
    authNames,
  );
}