EntityContact class

Constructors

EntityContact({int entityId, int contactAssetModelId, int contactId, DateTime dateCreated, DateTime dateModified, EntityContactRoleEnum role, String contactExternalIdentifier, String contactName, String contactDescription, ContactInfo contact})
Returns a new EntityContact instance.

Properties

contact ContactInfo
getter/setter pair
contactAssetModelId int
getter/setter pair
contactDescription String
getter/setter pair
contactExternalIdentifier String
getter/setter pair
contactId int
getter/setter pair
contactName String
getter/setter pair
dateCreated DateTime
getter/setter pair
dateModified DateTime
getter/setter pair
entityId int
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
role EntityContactRoleEnum
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) EntityContact
Returns a new EntityContact instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<EntityContact>
mapFromJson(dynamic json) Map<String, EntityContact>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<EntityContact>>