EntityMatchDescriptor class
Constructors
- EntityMatchDescriptor({String matchType, int targetEntityId, EntityBase targetEntity, int percentConfidence})
- Returns a new EntityMatchDescriptor instance.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- matchType ↔ String
-
getter/setter pair
- percentConfidence ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetEntity ↔ EntityBase
-
getter/setter pair
- targetEntityId ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → EntityMatchDescriptor -
Returns a new EntityMatchDescriptor instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< EntityMatchDescriptor> -
mapFromJson(
dynamic json) → Map< String, EntityMatchDescriptor> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< EntityMatchDescriptor> >