EntityMatchInfo class

Constructors

EntityMatchInfo({int sourceEntityId, EntityBase sourceEntity, List<EntityMatchDescriptor> matches = const []})
Returns a new EntityMatchInfo instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
matches List<EntityMatchDescriptor>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceEntity EntityBase
getter/setter pair
sourceEntityId int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) EntityMatchInfo
Returns a new EntityMatchInfo instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<EntityMatchInfo>
mapFromJson(dynamic json) Map<String, EntityMatchInfo>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<EntityMatchInfo>>