EntityRef class

Constructors

EntityRef({String ifcGuid, int assetModelId, int assetId, int entityId, String externalIdentifier, String name, DateTime dateCreated, String externalObjectName})
Returns a new EntityRef instance.

Properties

assetId int
getter/setter pair
assetModelId int
getter/setter pair
dateCreated DateTime
getter/setter pair
entityId int
getter/setter pair
externalIdentifier String
getter/setter pair
externalObjectName String
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
ifcGuid String
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) EntityRef
Returns a new EntityRef instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<EntityRef>
mapFromJson(dynamic json) Map<String, EntityRef>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<EntityRef>>