IMeteredResource class

Constructors

IMeteredResource({int limit, int used, int remaining, String unit, bool limitExceeded})
Returns a new IMeteredResource instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
limit int
getter/setter pair
limitExceeded bool
getter/setter pair
remaining int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unit String
getter/setter pair
used int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) IMeteredResource
Returns a new IMeteredResource instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<IMeteredResource>
mapFromJson(dynamic json) Map<String, IMeteredResource>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<IMeteredResource>>