IfcType class

Constructors

IfcType({String externalObjectType, String name, String description, List<ClassificationNode> classifications = const []})
Returns a new IfcType instance.

Properties

classifications List<ClassificationNode>
getter/setter pair
description String
getter/setter pair
externalObjectType String
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) IfcType
Returns a new IfcType instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<IfcType>
mapFromJson(dynamic json) Map<String, IfcType>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<IfcType>>