InlineObject class

Constructors

InlineObject({@required String roleId, @required String userId, String userName, @required InlineObjectMemberTypeEnum memberType})
Returns a new InlineObject instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
memberType InlineObjectMemberTypeEnum
getter/setter pair
roleId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
getter/setter pair
userName String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) InlineObject
Returns a new InlineObject instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<InlineObject>
mapFromJson(dynamic json) Map<String, InlineObject>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<InlineObject>>