InlineObject2 class

Constructors

InlineObject2({List<String> ifcGuids = const []})
Returns a new InlineObject2 instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
ifcGuids List<String>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) InlineObject2
Returns a new InlineObject2 instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<InlineObject2>
mapFromJson(dynamic json) Map<String, InlineObject2>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<InlineObject2>>