InlineObject3 class

Constructors

InlineObject3({@required int assetId})
Returns a new InlineObject3 instance.

Properties

assetId int
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) InlineObject3
Returns a new InlineObject3 instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<InlineObject3>
mapFromJson(dynamic json) Map<String, InlineObject3>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<InlineObject3>>