InlineObject4 class
Constructors
- InlineObject4({@required String roleId, @required String userId, String userName, @required InlineObject4MemberTypeEnum memberType})
- Returns a new InlineObject4 instance.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- memberType ↔ InlineObject4MemberTypeEnum
-
getter/setter pair
- roleId ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId ↔ String
-
getter/setter pair
- userName ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → InlineObject4 -
Returns a new InlineObject4 instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< InlineObject4> -
mapFromJson(
dynamic json) → Map< String, InlineObject4> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< InlineObject4> >