decode method

InlineObject4MemberTypeEnum decode(
  1. dynamic data, {
  2. bool allowNull,
})

Decodes a data to a InlineObject4MemberTypeEnum.

If allowNull is true and the data cannot be decoded successfully, then null is returned. However, if allowNull is false and the data cannot be decoded successfully, then an UnimplementedError is thrown.

The allowNull is very handy when an API changes and a new enum value is added or removed, and users are still using an old app with the old code.

Implementation

InlineObject4MemberTypeEnum decode(dynamic data, {bool allowNull}) {
  if (data != null) {
    switch (data.toString()) {
      case r'User': return InlineObject4MemberTypeEnum.user;
      case r'Invite': return InlineObject4MemberTypeEnum.invite;
      default:
        if (allowNull == false) {
          throw ArgumentError('Unknown enum value to decode: $data');
        }
    }
  }
  return null;
}