JobCreate class
Constructors
Properties
- assetModelId ↔ int
-
The identifier of the Model this entity belongs to
getter/setter pair
- componentTypeId ↔ int
-
getter/setter pair
- description ↔ String
-
Optional Description of the document
getter/setter pair
- entityId ↔ int
-
Gets or sets the entity identifier / Label.
getter/setter pair
- externalIdentifier ↔ String
-
The immutable unique identifier key for this Entity
getter/setter pair
- externalObjectType ↔ String
-
A system identifier of the type of entity
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- name ↔ String
-
The name of the entity
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → JobCreate -
Returns a new JobCreate instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< JobCreate> -
mapFromJson(
dynamic json) → Map< String, JobCreate> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< JobCreate> >