JobsApi class
Methods
-
jobsAddDocumentByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, DocumentCreate document)
→ Future<Document>
-
Adds a new document to a model entity
-
jobsAddDocumentByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, DocumentCreate document)
→ Future<Response>
-
Adds a new document to a model entity
-
jobsAsOfByDateAndTenantid(DateTime date, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<ODataListResponseOfEntity>
-
Get Jobs as of by date and tenantid
-
jobsAsOfByDateAndTenantidWithHttpInfo(DateTime date, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<Response>
-
Get Jobs as of by date and tenantid
-
jobsGetAvailablePropertiesByAssetidAndTenantid(int assetId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<ODataListResponseOfAttributeDefinition>
-
Gets the Properties available on this Model
-
jobsGetAvailablePropertiesByAssetidAndTenantidWithHttpInfo(int assetId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<Response>
-
Gets the Properties available on this Model
-
jobsGetByTenantid(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<ODataListResponseOfJob>
-
Returns the EntitySet Jobs
-
jobsGetByTenantidWithHttpInfo(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<Response>
-
Returns the EntitySet Jobs
-
jobsGetSingleEntityByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, {String dollarExpand, String dollarSelect})
→ Future<Job>
-
Get Jobs single entity by assetmodelid, entityid and tenantid
-
jobsGetSingleEntityByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, {String dollarExpand, String dollarSelect})
→ Future<Response>
-
Get Jobs single entity by assetmodelid, entityid and tenantid
-
jobsPatchByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, JobEdit patch_)
→ Future<Entity>
-
Patch Jobs by assetmodelid, entityid and tenantid
-
jobsPatchByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, JobEdit patch_)
→ Future<Response>
-
Patch Jobs by assetmodelid, entityid and tenantid
-
jobsPostByTenantid(String tenantId, String region, JobCreate job)
→ Future<Entity>
-
Post a new entity to EntitySet Jobs
-
jobsPostByTenantidWithHttpInfo(String tenantId, String region, JobCreate job)
→ Future<Response>
-
Post a new entity to EntitySet Jobs
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited