LevelsApi class

Constructors

LevelsApi([ApiClient apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

levelsAddDocumentByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, DocumentCreate document) Future<Document>
Adds a new document to a model entity
levelsAddDocumentByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, DocumentCreate document) Future<Response>
Adds a new document to a model entity
levelsAsOfByDateAndTenantid(DateTime date, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<ODataListResponseOfEntity>
Get Levels as of by date and tenantid
levelsAsOfByDateAndTenantidWithHttpInfo(DateTime date, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<Response>
Get Levels as of by date and tenantid
levelsGetAvailablePropertiesByAssetidAndTenantid(int assetId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<ODataListResponseOfAttributeDefinition>
Gets the Properties available on this Model
levelsGetAvailablePropertiesByAssetidAndTenantidWithHttpInfo(int assetId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<Response>
Gets the Properties available on this Model
levelsGetByTenantid(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<ODataListResponseOfLevel>
Returns the EntitySet Levels
levelsGetByTenantidWithHttpInfo(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<Response>
Returns the EntitySet Levels
levelsGetSingleEntityByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, {String dollarExpand, String dollarSelect}) Future<Level>
Get Levels single entity by assetmodelid, entityid and tenantid
levelsGetSingleEntityByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, {String dollarExpand, String dollarSelect}) Future<Response>
Get Levels single entity by assetmodelid, entityid and tenantid
levelsPatchByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, LevelEdit patch_) Future<Entity>
Patch Levels by assetmodelid, entityid and tenantid
levelsPatchByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, LevelEdit patch_) Future<Response>
Patch Levels by assetmodelid, entityid and tenantid
levelsPostByTenantid(String tenantId, String region, LevelCreate level) Future<Entity>
Post a new entity to EntitySet Levels
levelsPostByTenantidWithHttpInfo(String tenantId, String region, LevelCreate level) Future<Response>
Post a new entity to EntitySet Levels
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited