MappingMessageInfo class

Constructors

MappingMessageInfo({String mappingId, int ordinal, String messageType, String source_, String message, int assetModelId, int entityId, String entityType})
Returns a new MappingMessageInfo instance.

Properties

assetModelId int
getter/setter pair
entityId int
getter/setter pair
entityType String
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
mappingId String
getter/setter pair
message String
getter/setter pair
messageType String
getter/setter pair
ordinal int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source_ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) MappingMessageInfo
Returns a new MappingMessageInfo instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<MappingMessageInfo>
mapFromJson(dynamic json) Map<String, MappingMessageInfo>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<MappingMessageInfo>>