MappingProperties class
Constructors
- MappingProperties({bool hasFootprints, bool footPrintsAreAligned})
- Returns a new MappingProperties instance.
Properties
- footPrintsAreAligned ↔ bool
-
getter/setter pair
- hasFootprints ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → MappingProperties -
Returns a new MappingProperties instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< MappingProperties> -
mapFromJson(
dynamic json) → Map< String, MappingProperties> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< MappingProperties> >