MemberPermission class
Constructors
-
MemberPermission({String userId, List<
MemberRole> roles = const [], String name, MemberPermissionMemberTypeEnum memberType, List<MemberPermissionEffectivePermissionSetEnum> effectivePermissionSet = const []}) - Returns a new MemberPermission instance.
Properties
-
effectivePermissionSet
↔ List<
MemberPermissionEffectivePermissionSetEnum> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- memberType ↔ MemberPermissionMemberTypeEnum
-
getter/setter pair
- name ↔ String
-
getter/setter pair
-
roles
↔ List<
MemberRole> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → MemberPermission -
Returns a new MemberPermission instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< MemberPermission> -
mapFromJson(
dynamic json) → Map< String, MemberPermission> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< MemberPermission> >