Model class
Constructors
-
Model({List<
Object> entities = const [], Object asset, Object segment, List<AttributeDefinitionEntity> attributeDefinitions = const [], List<Object> spaces = const [], List<Object> components = const [], List<Object> componentTypes = const [], List<Object> levels = const [], List<Object> zones = const [], List<Object> facilities = const [], List<Object> documents = const [], List<Object> contacts = const [], List<Object> sites = const [], List<Application> applications = const [], List<ModelMapping> forwardMappings = const [], List<ModelMapping> reverseMappings = const [], List<Role> roles = const [], UserPermissions permissions, ModelStateEnum state, int assetModelId, int assetId, String name, String revision, String status, bool isCurrent, String uploadedById, String segmentName, String segmentId, String assetName, String modelPath, int modelSize, double oneMeter, int originalAuthorId, DateTime dateUploaded, DateTime dateProcessed, int lastEntityId, String processingStage, String processingStatus}) - Returns a new Model instance.
Properties
-
applications
↔ List<
Application> -
getter/setter pair
- asset ↔ Object
-
See #/definitions/Asset
getter/setter pair
- assetId ↔ int
-
getter/setter pair
- assetModelId ↔ int
-
getter/setter pair
- assetName ↔ String
-
getter/setter pair
-
attributeDefinitions
↔ List<
AttributeDefinitionEntity> -
getter/setter pair
-
components
↔ List<
Object> -
getter/setter pair
-
componentTypes
↔ List<
Object> -
getter/setter pair
-
contacts
↔ List<
Object> -
getter/setter pair
- dateProcessed ↔ DateTime
-
getter/setter pair
- dateUploaded ↔ DateTime
-
getter/setter pair
-
documents
↔ List<
Object> -
getter/setter pair
-
entities
↔ List<
Object> -
getter/setter pair
-
facilities
↔ List<
Object> -
getter/setter pair
-
forwardMappings
↔ List<
ModelMapping> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- isCurrent ↔ bool
-
getter/setter pair
- lastEntityId ↔ int
-
getter/setter pair
-
levels
↔ List<
Object> -
getter/setter pair
- modelPath ↔ String
-
getter/setter pair
- modelSize ↔ int
-
getter/setter pair
- name ↔ String
-
getter/setter pair
- oneMeter ↔ double
-
getter/setter pair
- originalAuthorId ↔ int
-
getter/setter pair
- permissions ↔ UserPermissions
-
getter/setter pair
- processingStage ↔ String
-
getter/setter pair
- processingStatus ↔ String
-
getter/setter pair
-
reverseMappings
↔ List<
ModelMapping> -
getter/setter pair
- revision ↔ String
-
getter/setter pair
-
roles
↔ List<
Role> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- segment ↔ Object
-
See #/definitions/AssetSegment
getter/setter pair
- segmentId ↔ String
-
getter/setter pair
- segmentName ↔ String
-
getter/setter pair
-
sites
↔ List<
Object> -
getter/setter pair
-
spaces
↔ List<
Object> -
getter/setter pair
- state ↔ ModelStateEnum
-
getter/setter pair
- status ↔ String
-
getter/setter pair
- uploadedById ↔ String
-
getter/setter pair
-
zones
↔ List<
Object> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → Model -
Returns a new Model instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< Model> -
mapFromJson(
dynamic json) → Map< String, Model> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< Model> >