toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() => 'Model[entities=$entities, asset=$asset, segment=$segment, attributeDefinitions=$attributeDefinitions, spaces=$spaces, components=$components, componentTypes=$componentTypes, levels=$levels, zones=$zones, facilities=$facilities, documents=$documents, contacts=$contacts, sites=$sites, applications=$applications, forwardMappings=$forwardMappings, reverseMappings=$reverseMappings, roles=$roles, permissions=$permissions, state=$state, assetModelId=$assetModelId, assetId=$assetId, name=$name, revision=$revision, status=$status, isCurrent=$isCurrent, uploadedById=$uploadedById, segmentName=$segmentName, segmentId=$segmentId, assetName=$assetName, modelPath=$modelPath, modelSize=$modelSize, oneMeter=$oneMeter, originalAuthorId=$originalAuthorId, dateUploaded=$dateUploaded, dateProcessed=$dateProcessed, lastEntityId=$lastEntityId, processingStage=$processingStage, processingStatus=$processingStatus]';