ModelFilesApi class

Constructors

ModelFilesApi([ApiClient apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

modelFilesGetFile(int assetId, int modelId, String tenantId, String region) Future<MultipartFile>
Downloads the model as originally uploaded
modelFilesGetFileWithHttpInfo(int assetId, int modelId, String tenantId, String region) Future<Response>
Downloads the model as originally uploaded
modelFilesUploadSingleFile(String tenantId, String region, MultipartFile file, String assetName, {String segmentName, String revision, String status, int assetId, int modelId, String originalFilename}) Future<FileUploadResult>
A one-stop service for Uploading an IFC model file, creating an asset and Model as required, and initiating processing
modelFilesUploadSingleFileWithHttpInfo(String tenantId, String region, MultipartFile file, String assetName, {String segmentName, String revision, String status, int assetId, int modelId, String originalFilename}) Future<Response>
A one-stop service for Uploading an IFC model file, creating an asset and Model as required, and initiating processing
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited