ModelInfo class

Constructors

ModelInfo({int assetModelId, int assetId, String name, String revision, String status, bool isCurrent, String uploadedById, String segmentName, String segmentId, String assetName, String modelPath, int modelSize, double oneMeter, int originalAuthorId, DateTime dateUploaded, DateTime dateProcessed, int lastEntityId, String processingStage, String processingStatus})
Returns a new ModelInfo instance.

Properties

assetId int
getter/setter pair
assetModelId int
getter/setter pair
assetName String
getter/setter pair
dateProcessed DateTime
getter/setter pair
dateUploaded DateTime
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
isCurrent bool
getter/setter pair
lastEntityId int
getter/setter pair
modelPath String
getter/setter pair
modelSize int
getter/setter pair
name String
getter/setter pair
oneMeter double
getter/setter pair
originalAuthorId int
getter/setter pair
processingStage String
getter/setter pair
processingStatus String
getter/setter pair
revision String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segmentId String
getter/setter pair
segmentName String
getter/setter pair
status String
getter/setter pair
uploadedById String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ModelInfo
Returns a new ModelInfo instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<ModelInfo>
mapFromJson(dynamic json) Map<String, ModelInfo>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<ModelInfo>>