ModelMapping class

Constructors

ModelMapping({String mappingId, int sourceAssetModelId, int targetAssetModelId, int createdByAssetModelId, int createdByContactId, Contact createdBy, ModelInfo sourceAssetModel, ModelInfo targetAssetModel, DateTime dateCreated, bool hasFootprints, bool footPrintsAreAligned, List<Entity> lostEntities = const [], List<Entity> foundEntities = const [], List<EntityMappingInfo> mappedEntities = const [], List<EntityMatchInfo> candidateMatches = const [], List<MappingMessageInfo> messages = const []})
Returns a new ModelMapping instance.

Properties

candidateMatches List<EntityMatchInfo>
getter/setter pair
createdBy Contact
getter/setter pair
createdByAssetModelId int
getter/setter pair
createdByContactId int
getter/setter pair
dateCreated DateTime
getter/setter pair
footPrintsAreAligned bool
getter/setter pair
foundEntities List<Entity>
getter/setter pair
hasFootprints bool
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
lostEntities List<Entity>
getter/setter pair
mappedEntities List<EntityMappingInfo>
getter/setter pair
mappingId String
getter/setter pair
messages List<MappingMessageInfo>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceAssetModel ModelInfo
getter/setter pair
sourceAssetModelId int
getter/setter pair
targetAssetModel ModelInfo
getter/setter pair
targetAssetModelId int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ModelMapping
Returns a new ModelMapping instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<ModelMapping>
mapFromJson(dynamic json) Map<String, ModelMapping>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<ModelMapping>>