ModelMappingApi class

Constructors

ModelMappingApi([ApiClient apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

modelMappingGetByMappingidAndTenantid(String mappingId, String tenantId, String region, {String dollarExpand, String dollarSelect}) Future<ModelMapping>
Get a single Mapping by its key
modelMappingGetByMappingidAndTenantidWithHttpInfo(String mappingId, String tenantId, String region, {String dollarExpand, String dollarSelect}) Future<Response>
Get a single Mapping by its key
modelMappingGetByTenantid(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<ODataListResponseOfModelMapping>
Returns the EntitySet ModelMapping
modelMappingGetByTenantidWithHttpInfo(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<Response>
Returns the EntitySet ModelMapping
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited