toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() => 'ModelMappingReport[sourceModelId=$sourceModelId, targetModelId=$targetModelId, mappingId=$mappingId, sourceEntityCount=$sourceEntityCount, targetEntityCount=$targetEntityCount, mappedEntities=$mappedEntities, candidateMatches=$candidateMatches, foundEntities=$foundEntities, lostEntities=$lostEntities, messages=$messages, mappedCount=$mappedCount, partialMatchCount=$partialMatchCount, foundCount=$foundCount, lostCount=$lostCount, mappingProperties=$mappingProperties]';