modelsGetByTenantid method
Returns the EntitySet Models
Summary:Returns the EntitySet Models.
Return Type: ODataListResponseOfModel
For more information about OData responses link.
Parameters:
-
String tenantId (required): The unique Tenant ID (UUID or Identifier string)
-
String region (required): The data center region the data resides in
-
String dollarExpand: Expands related entities inline.
-
String dollarFilter: Filters the results, based on a Boolean condition.
-
String dollarSelect: Selects which properties to include in the response.
-
String dollarOrderby: Sorts the results.
-
int dollarTop: Returns only the first n results.
-
int dollarSkip: Skips the first n results.
-
bool dollarCount: Includes a count of the matching results in the response.
Implementation
Future<ODataListResponseOfModel> modelsGetByTenantid(String tenantId, String region, { String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount, }) async {
final response = await modelsGetByTenantidWithHttpInfo(tenantId, region, dollarExpand: dollarExpand, dollarFilter: dollarFilter, dollarSelect: dollarSelect, dollarOrderby: dollarOrderby, dollarTop: dollarTop, dollarSkip: dollarSkip, dollarCount: dollarCount, );
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body != null && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'ODataListResponseOfModel',) as ODataListResponseOfModel;
}
return Future<ODataListResponseOfModel>.value();
}