modelsMoveByTenantidAndAssetmodelid method

Future<Model> modelsMoveByTenantidAndAssetmodelid(
  1. String tenantId,
  2. int assetModelId,
  3. String region,
  4. InlineObject3 modelMoveParameters,
)

Move a model to another asset in this tenant

Summary:Move a model to another asset in this tenant.
Return Type: Model

Parameters:

  • String tenantId (required): The unique Tenant ID (UUID or Identifier string)

  • int assetModelId (required): The Model ID

  • String region (required): The data center region the data resides in

  • InlineObject3 modelMoveParameters (required):

Implementation

Future<Model> modelsMoveByTenantidAndAssetmodelid(String tenantId, int assetModelId, String region, InlineObject3 modelMoveParameters,) async {
  final response = await modelsMoveByTenantidAndAssetmodelidWithHttpInfo(tenantId, assetModelId, region, modelMoveParameters,);
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body != null && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'Model',) as Model;

  }
  return Future<Model>.value();
}