modelsMoveByTenantidAndAssetmodelidWithHttpInfo method

Future<Response> modelsMoveByTenantidAndAssetmodelidWithHttpInfo(
  1. String tenantId,
  2. int assetModelId,
  3. String region,
  4. InlineObject3 modelMoveParameters,
)

Move a model to another asset in this tenant

Summary:Move a model to another asset in this tenant.
Return Type: Model

Note: This method returns the HTTP Response.

Parameters:

  • String tenantId (required): The unique Tenant ID (UUID or Identifier string)

  • int assetModelId (required): The Model ID

  • String region (required): The data center region the data resides in

  • InlineObject3 modelMoveParameters (required):

Implementation

Future<Response> modelsMoveByTenantidAndAssetmodelidWithHttpInfo(String tenantId, int assetModelId, String region, InlineObject3 modelMoveParameters,) async {
  // Verify required params are set.
  if (tenantId == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: tenantId');
  }
  if (assetModelId == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: assetModelId');
  }
  if (region == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: region');
  }
  if (modelMoveParameters == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: modelMoveParameters');
  }

  // ignore: prefer_const_declarations
  final path = r'/{region}/aim/2.0/{tenantId}/Models({AssetModelId})/Asset.Move'
    .replaceAll('{tenantId}', tenantId)
    .replaceAll('{AssetModelId}', assetModelId.toString())
    .replaceAll('{region}', region);

  // ignore: prefer_final_locals
  Object postBody = modelMoveParameters;

  final queryParams = <QueryParam>[];
  final headerParams = <String, String>{};
  final formParams = <String, String>{};

  const authNames = <String>['oauth2'];
  const contentTypes = <String>['application/json'];


  return apiClient.invokeAPI(
    path,
    'POST',
    queryParams,
    postBody,
    headerParams,
    formParams,
    contentTypes.isEmpty ? null : contentTypes[0],
    authNames,
  );
}