ODataListResponseOfComplexValueBase class

Constructors

ODataListResponseOfComplexValueBase({String atOdataPeriodNextLink, int atOdataPeriodCount, String atOdataPeriodContext, List<ComplexValueBase> value = const []})
Returns a new ODataListResponseOfComplexValueBase instance.

Properties

atOdataPeriodContext String
getter/setter pair
atOdataPeriodCount int
getter/setter pair
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value List<ComplexValueBase>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ODataListResponseOfComplexValueBase
Returns a new ODataListResponseOfComplexValueBase instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<ODataListResponseOfComplexValueBase>
mapFromJson(dynamic json) Map<String, ODataListResponseOfComplexValueBase>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<ODataListResponseOfComplexValueBase>>