ODataListResponseOfDocument class
Constructors
-
ODataListResponseOfDocument({String atOdataPeriodNextLink, int atOdataPeriodCount, String atOdataPeriodContext, List<
Document> value = const []}) - Returns a new ODataListResponseOfDocument instance.
Properties
- atOdataPeriodContext ↔ String
-
getter/setter pair
- atOdataPeriodCount ↔ int
-
getter/setter pair
- atOdataPeriodNextLink ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
↔ List<
Document> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → ODataListResponseOfDocument -
Returns a new ODataListResponseOfDocument instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< ODataListResponseOfDocument> -
mapFromJson(
dynamic json) → Map< String, ODataListResponseOfDocument> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< ODataListResponseOfDocument> >