QuotaStatus class
Constructors
- QuotaStatus({int limit, int remaining, int secondsToReset, QuotaStatusPeriodEnum period, QuotaStatusQuotaStateEnum quotaState})
- Returns a new QuotaStatus instance.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit ↔ int
-
getter/setter pair
- period ↔ QuotaStatusPeriodEnum
-
getter/setter pair
- quotaState ↔ QuotaStatusQuotaStateEnum
-
getter/setter pair
- remaining ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondsToReset ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → QuotaStatus -
Returns a new QuotaStatus instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< QuotaStatus> -
mapFromJson(
dynamic json) → Map< String, QuotaStatus> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< QuotaStatus> >