Resource class

Constructors

Resource({List<Object> jobs = const [], List<DocumentInfo> documents = const [], List<Object> documentEntities = const [], List<IssueInfo> issues = const [], List<EntityContact> contacts = const [], EntityContact createdBy, EntityContact modifiedBy, List<AttributeValue> attributes = const [], Footprint footprint, List<EntityMappingInfo> mappedFrom = const [], List<EntityMappingInfo> mappedTo = const [], IfcType ifcType, Map<String, Object> dynamicProperties = const {}, int assetModelId, int entityId, String name, String description, String externalIdentifier, String externalObjectType, String externalObjectName, ModelInfo model, String modelName, DateTime dateCreated, DateTime dateModified})
Returns a new Resource instance.

Properties

assetModelId int
getter/setter pair
attributes List<AttributeValue>
getter/setter pair
contacts List<EntityContact>
getter/setter pair
createdBy EntityContact
getter/setter pair
dateCreated DateTime
getter/setter pair
dateModified DateTime
getter/setter pair
description String
getter/setter pair
documentEntities List<Object>
getter/setter pair
documents List<DocumentInfo>
getter/setter pair
dynamicProperties Map<String, Object>
getter/setter pair
entityId int
getter/setter pair
externalIdentifier String
getter/setter pair
externalObjectName String
getter/setter pair
externalObjectType String
getter/setter pair
footprint Footprint
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
ifcType IfcType
getter/setter pair
issues List<IssueInfo>
getter/setter pair
jobs List<Object>
getter/setter pair
mappedFrom List<EntityMappingInfo>
getter/setter pair
mappedTo List<EntityMappingInfo>
getter/setter pair
model ModelInfo
getter/setter pair
modelName String
getter/setter pair
modifiedBy EntityContact
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Resource
Returns a new Resource instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<Resource>
mapFromJson(dynamic json) Map<String, Resource>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<Resource>>