resourcesGetSingleEntityByAssetmodelidAndEntityidAndTenantid method

Future<Resource> resourcesGetSingleEntityByAssetmodelidAndEntityidAndTenantid(
  1. int assetModelId,
  2. int entityId,
  3. String tenantId,
  4. String region, {
  5. String dollarExpand,
  6. String dollarSelect,
})

Get Resources single entity by assetmodelid, entityid and tenantid

Summary:Return Type: Resource

Parameters:

  • int assetModelId (required):

  • int entityId (required):

  • String tenantId (required): The unique Tenant ID (UUID or Identifier string)

  • String region (required): The data center region the data resides in

  • String dollarExpand: Expands related entities inline.

  • String dollarSelect: Selects which properties to include in the response.

Implementation

Future<Resource> resourcesGetSingleEntityByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, { String dollarExpand, String dollarSelect, }) async {
  final response = await resourcesGetSingleEntityByAssetmodelidAndEntityidAndTenantidWithHttpInfo(assetModelId, entityId, tenantId, region,  dollarExpand: dollarExpand, dollarSelect: dollarSelect, );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body != null && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'Resource',) as Resource;

  }
  return Future<Resource>.value();
}