RoleMember class

Constructors

RoleMember({String userId, DateTime dateCreated, RoleMemberMemberTypeEnum memberType, String name})
Returns a new RoleMember instance.

Properties

dateCreated DateTime
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
memberType RoleMemberMemberTypeEnum
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) RoleMember
Returns a new RoleMember instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<RoleMember>
mapFromJson(dynamic json) Map<String, RoleMember>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<RoleMember>>