RoleRoleLevelEnumTypeTransformer class

Transformation class that can encode an instance of RoleRoleLevelEnum to String, and decode dynamic data back to RoleRoleLevelEnum.

Constructors

RoleRoleLevelEnumTypeTransformer()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(dynamic data, {bool allowNull}) RoleRoleLevelEnum
Decodes a data to a RoleRoleLevelEnum.
encode(RoleRoleLevelEnum data) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited