Row class

Constructors

Row({int entityId, List<Cell> cells = const []})
Returns a new Row instance.

Properties

cells List<Cell>
getter/setter pair
entityId int
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Row
Returns a new Row instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<Row>
mapFromJson(dynamic json) Map<String, Row>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<Row>>