Schedule class

Constructors

Schedule({String scheduleName, int assetModelId, List<Row> rows = const [], List<ColumnDefinition> definitions = const [], bool imported})
Returns a new Schedule instance.

Properties

assetModelId int
getter/setter pair
definitions List<ColumnDefinition>
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
imported bool
getter/setter pair
rows List<Row>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduleName String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Schedule
Returns a new Schedule instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<Schedule>
mapFromJson(dynamic json) Map<String, Schedule>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<Schedule>>