SchedulesApi class

Constructors

SchedulesApi([ApiClient apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
schedulesGetScheduleByTenantid(int assetModelId, String scheduleName, String tenantId, String region, {String dollarExpand, String dollarSelect}) Future<Schedule>
Get Schedules schedule by tenantid
schedulesGetScheduleByTenantidWithHttpInfo(int assetModelId, String scheduleName, String tenantId, String region, {String dollarExpand, String dollarSelect}) Future<Response>
Get Schedules schedule by tenantid
schedulesGetScheduleRowsByAssetmodelidAndSchedulenameAndTenantid(int assetModelId, String scheduleName, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<ODataListResponseOfRow>
Get Schedules schedule rows by assetmodelid, schedulename and tenantid
schedulesGetScheduleRowsByAssetmodelidAndSchedulenameAndTenantidWithHttpInfo(int assetModelId, String scheduleName, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<Response>
Get Schedules schedule rows by assetmodelid, schedulename and tenantid
schedulesGetSchedulesByTenantid(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<ODataListResponseOfSchedule>
Returns the EntitySet Schedules
schedulesGetSchedulesByTenantidWithHttpInfo(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount}) Future<Response>
Returns the EntitySet Schedules
schedulesImportScheduleByModelidAndScheduleAndTenantid(int modelId, String schedule, String tenantId, String region) Future<Object>
Post Schedules import schedule by modelid, schedule and tenantid
schedulesImportScheduleByModelidAndScheduleAndTenantidWithHttpInfo(int modelId, String schedule, String tenantId, String region) Future<Response>
Post Schedules import schedule by modelid, schedule and tenantid
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited