SpaceEdit class

Constructors

SpaceEdit({int levelId, String name, String description, String externalObjectType})
Returns a new SpaceEdit instance.

Properties

description String
Optional Description of the document
getter/setter pair
externalObjectType String
A system identifier of the type of entity
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
levelId int
getter/setter pair
name String
The name of the entity
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SpaceEdit
Returns a new SpaceEdit instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<SpaceEdit>
mapFromJson(dynamic json) Map<String, SpaceEdit>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<SpaceEdit>>