SpaceInfo class

Constructors

SpaceInfo({String levelName, LevelInfo level, int assetModelId, int entityId, String name, String description, String externalIdentifier, String externalObjectType, String externalObjectName, ModelInfo model, String modelName, DateTime dateCreated, DateTime dateModified})
Returns a new SpaceInfo instance.

Properties

assetModelId int
getter/setter pair
dateCreated DateTime
getter/setter pair
dateModified DateTime
getter/setter pair
description String
getter/setter pair
entityId int
getter/setter pair
externalIdentifier String
getter/setter pair
externalObjectName String
getter/setter pair
externalObjectType String
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
level LevelInfo
getter/setter pair
levelName String
getter/setter pair
model ModelInfo
getter/setter pair
modelName String
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SpaceInfo
Returns a new SpaceInfo instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool emptyIsNull, bool growable}) List<SpaceInfo>
mapFromJson(dynamic json) Map<String, SpaceInfo>
mapListFromJson(dynamic json, {bool emptyIsNull, bool growable}) Map<String, List<SpaceInfo>>