spacesContainedComponentsByAssetmodelidAndEntityidAndTenantid method
Gets the set of Components which are placed within the Geometry footprint of this Space
Summary:Gets the set of Components which are placed within the Geometry footprint of this Space.
Returns all Components with geometry contained wholly or partly within the footprint of the space, and wholly or party within the Z-axis.
A 'tolerance' can be provided to extend or reduce the spaces included at the boundary of the space
.
Return Type: ODataListResponseOfComponent
For more information about OData responses link.
Parameters:
-
int assetModelId (required): The assetModel ID of the Space
-
int entityId (required): The ID of the space entity
-
String tenantId (required): The unique Tenant ID (UUID or Identifier string)
-
String region (required): The data center region the data resides in
-
String dollarExpand: Expands related entities inline.
-
String dollarFilter: Filters the results, based on a Boolean condition.
-
String dollarSelect: Selects which properties to include in the response.
-
String dollarOrderby: Sorts the results.
-
int dollarTop: Returns only the first n results.
-
int dollarSkip: Skips the first n results.
-
bool dollarCount: Includes a count of the matching results in the response.
-
double tolerance: Tolerance in millimeters. Can be negative. Default: 10mm
-
bool inSameAsset: Limit the results to spaces in the same Asset
Implementation
Future<ODataListResponseOfComponent> spacesContainedComponentsByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, { String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount, double tolerance, bool inSameAsset, }) async {
final response = await spacesContainedComponentsByAssetmodelidAndEntityidAndTenantidWithHttpInfo(assetModelId, entityId, tenantId, region, dollarExpand: dollarExpand, dollarFilter: dollarFilter, dollarSelect: dollarSelect, dollarOrderby: dollarOrderby, dollarTop: dollarTop, dollarSkip: dollarSkip, dollarCount: dollarCount, tolerance: tolerance, inSameAsset: inSameAsset, );
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body != null && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'ODataListResponseOfComponent',) as ODataListResponseOfComponent;
}
return Future<ODataListResponseOfComponent>.value();
}