statsMeteredResources method

Future<Map<String, IMeteredResource>> statsMeteredResources(
  1. String tenantId,
  2. String region
)

Lists the plan allowances and current consumpttion for a tenant's app

Summary:Lists the plan allowances and current consumpttion for a tenant's app.
Return Type:

Parameters:

  • String tenantId (required): The unique Tenant ID (UUID or Identifier string)

  • String region (required): The data center region the data resides in

Implementation

Future<Map<String, IMeteredResource>> statsMeteredResources(String tenantId, String region,) async {
  final response = await statsMeteredResourcesWithHttpInfo(tenantId, region,);
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body != null && response.statusCode != HttpStatus.noContent) {
    return Map<String, IMeteredResource>.from(await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'Map<String, IMeteredResource>'),);

  }
  return Future<Map<String, IMeteredResource>>.value();
}