statsMeteredResourcesWithHttpInfo method
Lists the plan allowances and current consumpttion for a tenant's app
Summary:Lists the plan allowances and current consumpttion for a tenant's app.
Return Type:
Note: This method returns the HTTP Response.
Parameters:
Implementation
Future<Response> statsMeteredResourcesWithHttpInfo(String tenantId, String region,) async {
// Verify required params are set.
if (tenantId == null) {
throw ApiException(HttpStatus.badRequest, 'Missing required param: tenantId');
}
if (region == null) {
throw ApiException(HttpStatus.badRequest, 'Missing required param: region');
}
// ignore: prefer_const_declarations
final path = r'/{region}/aim/2.0/{tenantId}/stats/planAllowances'
.replaceAll('{tenantId}', tenantId)
.replaceAll('{region}', region);
// ignore: prefer_final_locals
Object postBody;
final queryParams = <QueryParam>[];
final headerParams = <String, String>{};
final formParams = <String, String>{};
const authNames = <String>['oauth2'];
const contentTypes = <String>[];
return apiClient.invokeAPI(
path,
'GET',
queryParams,
postBody,
headerParams,
formParams,
contentTypes.isEmpty ? null : contentTypes[0],
authNames,
);
}