statsRateLimits method

Future<Map<String, QuotaStatus>> statsRateLimits(
  1. String tenantId,
  2. String region
)

Provides details of the permitted rate limits for tenant's app and user

Summary:Provides details of the permitted rate limits for tenant's app and user.
Return Type:

Parameters:

  • String tenantId (required): The unique Tenant ID (UUID or Identifier string)

  • String region (required): The data center region the data resides in

Implementation

Future<Map<String, QuotaStatus>> statsRateLimits(String tenantId, String region,) async {
  final response = await statsRateLimitsWithHttpInfo(tenantId, region,);
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body != null && response.statusCode != HttpStatus.noContent) {
    return Map<String, QuotaStatus>.from(await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'Map<String, QuotaStatus>'),);

  }
  return Future<Map<String, QuotaStatus>>.value();
}