ThumbnailsApi class

Constructors

ThumbnailsApi([ApiClient apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
thumbnailsGetAssetThumbnail(int assetId, String tenantId, String region) Future<MultipartFile>
Get Thumbnails asset thumbnail
thumbnailsGetAssetThumbnailWithHttpInfo(int assetId, String tenantId, String region) Future<Response>
Get Thumbnails asset thumbnail
thumbnailsPostAssetThumbnail(int assetId, String tenantId, String region) Future<Object>
Post Thumbnails asset thumbnail
thumbnailsPostAssetThumbnailWithHttpInfo(int assetId, String tenantId, String region) Future<Response>
Post Thumbnails asset thumbnail
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited