wexbimGetDynamic method

Future<MultipartFile> wexbimGetDynamic(
  1. int assetId,
  2. int modelId,
  3. List<String> included,
  4. String tenantId,
  5. String region, {
  6. List<String> excluded,
})

Gets a dynamically generated geometry stream for a model

Summary:Gets a dynamically generated geometry stream for a model.
Return Type: string

Parameters:

  • int assetId (required): The id of asset the model belongs to

  • int modelId (required): The id of the model

  • List<String> included (required): The IFC types to include (hierarchical)

  • String tenantId (required): The unique Tenant ID (UUID or Identifier string)

  • String region (required): The data center region the data resides in

  • List<String> excluded: The IFC types to exclude (hierarchical)

Implementation

Future<MultipartFile> wexbimGetDynamic(int assetId, int modelId, List<String> included, String tenantId, String region, { List<String> excluded, }) async {
  final response = await wexbimGetDynamicWithHttpInfo(assetId, modelId, included, tenantId, region,  excluded: excluded, );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body != null && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'MultipartFile',) as MultipartFile;

  }
  return Future<MultipartFile>.value();
}