wexbimGetDynamicWithHttpInfo method

Future<Response> wexbimGetDynamicWithHttpInfo(
  1. int assetId,
  2. int modelId,
  3. List<String> included,
  4. String tenantId,
  5. String region, {
  6. List<String> excluded,
})

Gets a dynamically generated geometry stream for a model

Summary:Gets a dynamically generated geometry stream for a model.
Return Type: string

Note: This method returns the HTTP Response.

Parameters:

  • int assetId (required): The id of asset the model belongs to

  • int modelId (required): The id of the model

  • List<String> included (required): The IFC types to include (hierarchical)

  • String tenantId (required): The unique Tenant ID (UUID or Identifier string)

  • String region (required): The data center region the data resides in

  • List<String> excluded: The IFC types to exclude (hierarchical)

Implementation

Future<Response> wexbimGetDynamicWithHttpInfo(int assetId, int modelId, List<String> included, String tenantId, String region, { List<String> excluded, }) async {
  // Verify required params are set.
  if (assetId == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: assetId');
  }
  if (modelId == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: modelId');
  }
  if (included == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: included');
  }
  if (tenantId == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: tenantId');
  }
  if (region == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: region');
  }

  // ignore: prefer_const_declarations
  final path = r'/{region}/aim/2.0/{tenantId}/wexbim/dynamic'
    .replaceAll('{tenantId}', tenantId)
    .replaceAll('{region}', region);

  // ignore: prefer_final_locals
  Object postBody;

  final queryParams = <QueryParam>[];
  final headerParams = <String, String>{};
  final formParams = <String, String>{};

    queryParams.addAll(_convertParametersForCollectionFormat('', 'assetId', assetId));
    queryParams.addAll(_convertParametersForCollectionFormat('', 'modelId', modelId));
    queryParams.addAll(_convertParametersForCollectionFormat('csv', 'included', included));
  if (excluded != null) {
    queryParams.addAll(_convertParametersForCollectionFormat('csv', 'excluded', excluded));
  }

  const authNames = <String>['oauth2'];
  const contentTypes = <String>[];


  return apiClient.invokeAPI(
    path,
    'GET',
    queryParams,
    postBody,
    headerParams,
    formParams,
    contentTypes.isEmpty ? null : contentTypes[0],
    authNames,
  );
}