wexbimGetEnvelopeCut method

Future<MultipartFile> wexbimGetEnvelopeCut(
  1. int assetId,
  2. int modelId,
  3. double bottom,
  4. double top,
  5. String tenantId,
  6. String region,
)

Gets the building envelope geometry cut plane. This can be used to cap the holes after clipping.

Summary:Gets the building envelope geometry cut plane. This can be used to cap the holes after clipping..
Return Type: string

Parameters:

  • int assetId (required):

  • int modelId (required):

  • double bottom (required):

  • double top (required):

  • String tenantId (required): The unique Tenant ID (UUID or Identifier string)

  • String region (required): The data center region the data resides in

Implementation

Future<MultipartFile> wexbimGetEnvelopeCut(int assetId, int modelId, double bottom, double top, String tenantId, String region,) async {
  final response = await wexbimGetEnvelopeCutWithHttpInfo(assetId, modelId, bottom, top, tenantId, region,);
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body != null && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'MultipartFile',) as MultipartFile;

  }
  return Future<MultipartFile>.value();
}