wexbimGetEnvelopeCutWithHttpInfo method

Future<Response> wexbimGetEnvelopeCutWithHttpInfo(
  1. int assetId,
  2. int modelId,
  3. double bottom,
  4. double top,
  5. String tenantId,
  6. String region,
)

Gets the building envelope geometry cut plane. This can be used to cap the holes after clipping.

Summary:Gets the building envelope geometry cut plane. This can be used to cap the holes after clipping..
Return Type: string

Note: This method returns the HTTP Response.

Parameters:

  • int assetId (required):

  • int modelId (required):

  • double bottom (required):

  • double top (required):

  • String tenantId (required): The unique Tenant ID (UUID or Identifier string)

  • String region (required): The data center region the data resides in

Implementation

Future<Response> wexbimGetEnvelopeCutWithHttpInfo(int assetId, int modelId, double bottom, double top, String tenantId, String region,) async {
  // Verify required params are set.
  if (assetId == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: assetId');
  }
  if (modelId == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: modelId');
  }
  if (bottom == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: bottom');
  }
  if (top == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: top');
  }
  if (tenantId == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: tenantId');
  }
  if (region == null) {
   throw ApiException(HttpStatus.badRequest, 'Missing required param: region');
  }

  // ignore: prefer_const_declarations
  final path = r'/{region}/aim/2.0/{tenantId}/wexbim/envelopecut'
    .replaceAll('{tenantId}', tenantId)
    .replaceAll('{region}', region);

  // ignore: prefer_final_locals
  Object postBody;

  final queryParams = <QueryParam>[];
  final headerParams = <String, String>{};
  final formParams = <String, String>{};

    queryParams.addAll(_convertParametersForCollectionFormat('', 'assetId', assetId));
    queryParams.addAll(_convertParametersForCollectionFormat('', 'modelId', modelId));
    queryParams.addAll(_convertParametersForCollectionFormat('', 'bottom', bottom));
    queryParams.addAll(_convertParametersForCollectionFormat('', 'top', top));

  const authNames = <String>['oauth2'];
  const contentTypes = <String>[];


  return apiClient.invokeAPI(
    path,
    'GET',
    queryParams,
    postBody,
    headerParams,
    formParams,
    contentTypes.isEmpty ? null : contentTypes[0],
    authNames,
  );
}