wexbimGetEnvelopeFreeCut method
Gets the a cutplane across the envelope for up to 6 cut planes.
Summary:Gets the a cutplane across the envelope for up to 6 cut planes..
Used to cap voids in the envelope when employing sections / section boxes.
Return Type: string
Parameters:
-
int assetId (required):
-
int modelId (required):
-
List<double> planes (required):
-
String tenantId (required): The unique Tenant ID (UUID or Identifier string)
-
String region (required): The data center region the data resides in
Implementation
Future<MultipartFile> wexbimGetEnvelopeFreeCut(int assetId, int modelId, List<double> planes, String tenantId, String region,) async {
final response = await wexbimGetEnvelopeFreeCutWithHttpInfo(assetId, modelId, planes, tenantId, region,);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body != null && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'MultipartFile',) as MultipartFile;
}
return Future<MultipartFile>.value();
}