wexbimGetEnvelopeFreeCutWithHttpInfo method
Gets the a cutplane across the envelope for up to 6 cut planes.
Summary:Gets the a cutplane across the envelope for up to 6 cut planes..
Used to cap voids in the envelope when employing sections / section boxes.
Return Type: string
Note: This method returns the HTTP Response.
Parameters:
-
int assetId (required):
-
int modelId (required):
-
List<double> planes (required):
-
String tenantId (required): The unique Tenant ID (UUID or Identifier string)
-
String region (required): The data center region the data resides in
Implementation
Future<Response> wexbimGetEnvelopeFreeCutWithHttpInfo(int assetId, int modelId, List<double> planes, String tenantId, String region,) async {
// Verify required params are set.
if (assetId == null) {
throw ApiException(HttpStatus.badRequest, 'Missing required param: assetId');
}
if (modelId == null) {
throw ApiException(HttpStatus.badRequest, 'Missing required param: modelId');
}
if (planes == null) {
throw ApiException(HttpStatus.badRequest, 'Missing required param: planes');
}
if (tenantId == null) {
throw ApiException(HttpStatus.badRequest, 'Missing required param: tenantId');
}
if (region == null) {
throw ApiException(HttpStatus.badRequest, 'Missing required param: region');
}
// ignore: prefer_const_declarations
final path = r'/{region}/aim/2.0/{tenantId}/wexbim/envelopefreecut'
.replaceAll('{tenantId}', tenantId)
.replaceAll('{region}', region);
// ignore: prefer_final_locals
Object postBody;
final queryParams = <QueryParam>[];
final headerParams = <String, String>{};
final formParams = <String, String>{};
queryParams.addAll(_convertParametersForCollectionFormat('', 'assetId', assetId));
queryParams.addAll(_convertParametersForCollectionFormat('', 'modelId', modelId));
queryParams.addAll(_convertParametersForCollectionFormat('csv', 'planes', planes));
const authNames = <String>['oauth2'];
const contentTypes = <String>[];
return apiClient.invokeAPI(
path,
'GET',
queryParams,
postBody,
headerParams,
formParams,
contentTypes.isEmpty ? null : contentTypes[0],
authNames,
);
}