AdminApi class
Properties
Methods
-
adminAppliedUpdates(
String region) → Future< List< DbUpdate> > - Lists the Database schema updates already installed
-
adminAppliedUpdatesWithHttpInfo(
String region) → Future< Response> - Lists the Database schema updates already installed
-
adminFlushCaches(
String region) → Future< void> - Flushes the Flex caches
-
adminFlushCachesWithHttpInfo(
String region) → Future< Response> - Flushes the Flex caches
-
adminGetIsCurrent(
String region) → Future< bool> - Returns a flag indicating if the database schema requires an upgrade
-
adminGetIsCurrentWithHttpInfo(
String region) → Future< Response> - Returns a flag indicating if the database schema requires an upgrade
-
adminPendingUpdates(
String region) → Future< List< DbUpdate> > - Lists the Database schema updates required
-
adminPendingUpdatesWithHttpInfo(
String region) → Future< Response> - Lists the Database schema updates required
-
adminUpdateSchema(
String region) → Future< void> - Updates the Database schemas to the latest version
-
adminUpdateSchemaWithHttpInfo(
String region) → Future< Response> - Updates the Database schemas to the latest version
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited