Application class
Constructors
- Application({int applicationId, @required String applicationIdentifier, String name, String version, String developer, String modelName, Model model})
- Returns a new Application instance.
Properties
- applicationId ↔ int
-
getter/setter pair
- applicationIdentifier ↔ String
-
getter/setter pair
- developer ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- model ↔ Model
-
getter/setter pair
- modelName ↔ String
-
getter/setter pair
- name ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → Application -
Returns a new Application instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< Application> -
mapFromJson(
dynamic json) → Map< String, Application> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< Application> >