AssembliesApi class
Methods
-
assembliesAddDocumentByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, DocumentCreate document)
→ Future<Document>
-
Adds a new document to a model entity
-
assembliesAddDocumentByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, DocumentCreate document)
→ Future<Response>
-
Adds a new document to a model entity
-
assembliesAsOfByDateAndTenantid(DateTime date, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<ODataListResponseOfEntity>
-
Get Assemblies as of by date and tenantid
-
assembliesAsOfByDateAndTenantidWithHttpInfo(DateTime date, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<Response>
-
Get Assemblies as of by date and tenantid
-
assembliesGetAvailablePropertiesByAssetidAndTenantid(int assetId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<ODataListResponseOfAttributeDefinition>
-
Gets the Properties available on this Model
-
assembliesGetAvailablePropertiesByAssetidAndTenantidWithHttpInfo(int assetId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<Response>
-
Gets the Properties available on this Model
-
assembliesGetByTenantid(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<ODataListResponseOfAssemblyItem>
-
Returns the EntitySet Assemblies
-
assembliesGetByTenantidWithHttpInfo(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<Response>
-
Returns the EntitySet Assemblies
-
assembliesGetSingleEntityByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, {String dollarExpand, String dollarSelect})
→ Future<AssemblyItem>
-
Get Assemblies single entity by assetmodelid, entityid and tenantid
-
assembliesGetSingleEntityByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, {String dollarExpand, String dollarSelect})
→ Future<Response>
-
Get Assemblies single entity by assetmodelid, entityid and tenantid
-
assembliesPatchByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, EntityEdit patch_)
→ Future<Entity>
-
Patch Assemblies by assetmodelid, entityid and tenantid
-
assembliesPatchByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, EntityEdit patch_)
→ Future<Response>
-
Patch Assemblies by assetmodelid, entityid and tenantid
-
assembliesPostByTenantid(String tenantId, String region, EntityCreate assemblyItem)
→ Future<Entity>
-
Post a new entity to EntitySet Assemblies
-
assembliesPostByTenantidWithHttpInfo(String tenantId, String region, EntityCreate assemblyItem)
→ Future<Response>
-
Post a new entity to EntitySet Assemblies
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited