AssetSegment class
Constructors
Properties
- asset ↔ Object
-
See #/definitions/Asset
getter/setter pair
- assetId ↔ int
-
getter/setter pair
- createdById ↔ String
-
getter/setter pair
- description ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- isDefault ↔ bool
-
getter/setter pair
-
modelEntities
↔ List<
Object> -
getter/setter pair
-
models
↔ List<
ModelInfo> -
getter/setter pair
- modifiedById ↔ String
-
getter/setter pair
- name ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- segmentId ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → AssetSegment -
Returns a new AssetSegment instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< AssetSegment> -
mapFromJson(
dynamic json) → Map< String, AssetSegment> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< AssetSegment> >