AttributeDefinitionEdit class
Constructors
- AttributeDefinitionEdit({String name, String groupName, AttributeDefinitionEditGroupTypeEnum groupType, String semanticType, String unit})
- Returns a new AttributeDefinitionEdit instance.
Properties
- groupName ↔ String
-
getter/setter pair
- groupType ↔ AttributeDefinitionEditGroupTypeEnum
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- name ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticType ↔ String
-
getter/setter pair
- unit ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → AttributeDefinitionEdit -
Returns a new AttributeDefinitionEdit instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< AttributeDefinitionEdit> -
mapFromJson(
dynamic json) → Map< String, AttributeDefinitionEdit> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< AttributeDefinitionEdit> >