attributesPostByTenantid method
Future<AttributeDefinitionEntity>
attributesPostByTenantid(
- String tenantId,
- String region,
- AttributeDefinitionCreate attributeDefinitionEntity
Creates a new AttributeDefinition for a model
Summary:Creates a new AttributeDefinition for a model.
'EditPermissions' for a model is required to create an attribute.
Return Type: AttributeDefinitionEntity
Parameters:
-
String tenantId (required): The unique Tenant ID (UUID or Identifier string)
-
String region (required): The data center region the data resides in
-
AttributeDefinitionCreate attributeDefinitionEntity (required): The entity to post
Implementation
Future<AttributeDefinitionEntity> attributesPostByTenantid(String tenantId, String region, AttributeDefinitionCreate attributeDefinitionEntity,) async {
final response = await attributesPostByTenantidWithHttpInfo(tenantId, region, attributeDefinitionEntity,);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body != null && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'AttributeDefinitionEntity',) as AttributeDefinitionEntity;
}
return Future<AttributeDefinitionEntity>.value();
}