ColumnDefinition class
Constructors
- ColumnDefinition({int id, String name, bool imported, String semanticType, String unit, ColumnDefinitionDataTypeEnum dataType})
- Returns a new ColumnDefinition instance.
Properties
- dataType ↔ ColumnDefinitionDataTypeEnum
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- id ↔ int
-
getter/setter pair
- imported ↔ bool
-
getter/setter pair
- name ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticType ↔ String
-
getter/setter pair
- unit ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → ColumnDefinition -
Returns a new ColumnDefinition instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< ColumnDefinition> -
mapFromJson(
dynamic json) → Map< String, ColumnDefinition> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< ColumnDefinition> >