Component class
Constructors
-
Component({int componentTypeId, String componentTypeName, ComponentTypeInfo componentType, List<
ComponentInfo> connectedFrom = const [], List<ComponentInfo> connectedTo = const [], List<SpaceInfo> spaces = const [], List<SystemInfo> systems = const [], Object componentTypeEntity, List<Object> spaceEntities = const [], List<AssemblyInfo> subAssemblies = const [], List<AssemblyInfo> parentAssemblies = const [], List<DocumentInfo> documents = const [], List<Object> documentEntities = const [], List<IssueInfo> issues = const [], List<EntityContact> contacts = const [], EntityContact createdBy, EntityContact modifiedBy, List<AttributeValue> attributes = const [], Footprint footprint, List<EntityMappingInfo> mappedFrom = const [], List<EntityMappingInfo> mappedTo = const [], IfcType ifcType, int assetModelId, int entityId, String name, String description, String externalIdentifier, String externalObjectType, String externalObjectName, ModelInfo model, String modelName, DateTime dateCreated, DateTime dateModified}) - Returns a new Component instance.
Properties
- assetModelId ↔ int
-
getter/setter pair
-
attributes
↔ List<
AttributeValue> -
getter/setter pair
- componentType ↔ ComponentTypeInfo
-
getter/setter pair
- componentTypeEntity ↔ Object
-
See #/definitions/ComponentType
getter/setter pair
- componentTypeId ↔ int
-
getter/setter pair
- componentTypeName ↔ String
-
getter/setter pair
-
connectedFrom
↔ List<
ComponentInfo> -
getter/setter pair
-
connectedTo
↔ List<
ComponentInfo> -
getter/setter pair
-
contacts
↔ List<
EntityContact> -
getter/setter pair
- createdBy ↔ EntityContact
-
getter/setter pair
- dateCreated ↔ DateTime
-
getter/setter pair
- dateModified ↔ DateTime
-
getter/setter pair
- description ↔ String
-
getter/setter pair
-
documentEntities
↔ List<
Object> -
getter/setter pair
-
documents
↔ List<
DocumentInfo> -
getter/setter pair
- entityId ↔ int
-
getter/setter pair
- externalIdentifier ↔ String
-
getter/setter pair
- externalObjectName ↔ String
-
getter/setter pair
- externalObjectType ↔ String
-
getter/setter pair
- footprint ↔ Footprint
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- ifcType ↔ IfcType
-
getter/setter pair
-
issues
↔ List<
IssueInfo> -
getter/setter pair
-
mappedFrom
↔ List<
EntityMappingInfo> -
getter/setter pair
-
mappedTo
↔ List<
EntityMappingInfo> -
getter/setter pair
- model ↔ ModelInfo
-
getter/setter pair
- modelName ↔ String
-
getter/setter pair
- modifiedBy ↔ EntityContact
-
getter/setter pair
- name ↔ String
-
getter/setter pair
-
parentAssemblies
↔ List<
AssemblyInfo> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
spaceEntities
↔ List<
Object> -
getter/setter pair
-
spaces
↔ List<
SpaceInfo> -
getter/setter pair
-
subAssemblies
↔ List<
AssemblyInfo> -
getter/setter pair
-
systems
↔ List<
SystemInfo> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → Component -
Returns a new Component instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< Component> -
mapFromJson(
dynamic json) → Map< String, Component> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< Component> >