ComponentsApi class
Methods
-
componentsAddDocumentByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, DocumentCreate document)
→ Future<Document>
-
Adds a new document to a model entity
-
componentsAddDocumentByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, DocumentCreate document)
→ Future<Response>
-
Adds a new document to a model entity
-
componentsAsOfByDateAndTenantid(DateTime date, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<ODataListResponseOfEntity>
-
Get Components as of by date and tenantid
-
componentsAsOfByDateAndTenantidWithHttpInfo(DateTime date, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<Response>
-
Get Components as of by date and tenantid
-
componentsContainingSpacesByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount, double tolerance, bool inSameAsset})
→ Future<ODataListResponseOfSpace>
-
Gets the Spaces this Component is placed in, based on Footprint data
-
componentsContainingSpacesByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount, double tolerance, bool inSameAsset})
→ Future<Response>
-
Gets the Spaces this Component is placed in, based on Footprint data
-
componentsGetAvailablePropertiesByAssetidAndTenantid(int assetId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<ODataListResponseOfAttributeDefinition>
-
Gets the Properties available on this Model
-
componentsGetAvailablePropertiesByAssetidAndTenantidWithHttpInfo(int assetId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<Response>
-
Gets the Properties available on this Model
-
componentsGetByTenantid(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<ODataListResponseOfComponent>
-
Returns the EntitySet Components
-
componentsGetByTenantidWithHttpInfo(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<Response>
-
Returns the EntitySet Components
-
componentsGetSingleEntityByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, {String dollarExpand, String dollarSelect})
→ Future<Component>
-
Get Components single entity by assetmodelid, entityid and tenantid
-
componentsGetSingleEntityByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, {String dollarExpand, String dollarSelect})
→ Future<Response>
-
Get Components single entity by assetmodelid, entityid and tenantid
-
componentsPatchByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, ComponentEdit patch_)
→ Future<Entity>
-
Edit an existing component
-
componentsPatchByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, ComponentEdit patch_)
→ Future<Response>
-
Edit an existing component
-
componentsPostByTenantid(String tenantId, String region, ComponentCreate component)
→ Future<Component>
-
Adds a new Component to a model
-
componentsPostByTenantidWithHttpInfo(String tenantId, String region, ComponentCreate component)
→ Future<Response>
-
Adds a new Component to a model
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited