ContactsApi class
Methods
-
contactsAddDocumentByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, DocumentCreate document)
→ Future<Document>
-
Adds a new document to a model entity
-
contactsAddDocumentByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, DocumentCreate document)
→ Future<Response>
-
Adds a new document to a model entity
-
contactsAsOfByDateAndTenantid(DateTime date, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<ODataListResponseOfEntity>
-
Get Contacts as of by date and tenantid
-
contactsAsOfByDateAndTenantidWithHttpInfo(DateTime date, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<Response>
-
Get Contacts as of by date and tenantid
-
contactsGetAvailablePropertiesByAssetidAndTenantid(int assetId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<ODataListResponseOfAttributeDefinition>
-
Gets the Properties available on this Model
-
contactsGetAvailablePropertiesByAssetidAndTenantidWithHttpInfo(int assetId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<Response>
-
Gets the Properties available on this Model
-
contactsGetByTenantid(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<ODataListResponseOfContact>
-
Returns the EntitySet Contacts
-
contactsGetByTenantidWithHttpInfo(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<Response>
-
Returns the EntitySet Contacts
-
contactsGetSingleEntityByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, {String dollarExpand, String dollarSelect})
→ Future<Contact>
-
Get Contacts single entity by assetmodelid, entityid and tenantid
-
contactsGetSingleEntityByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, {String dollarExpand, String dollarSelect})
→ Future<Response>
-
Get Contacts single entity by assetmodelid, entityid and tenantid
-
contactsPatchByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, EntityEdit patch_)
→ Future<Entity>
-
Patch Contacts by assetmodelid, entityid and tenantid
-
contactsPatchByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, EntityEdit patch_)
→ Future<Response>
-
Patch Contacts by assetmodelid, entityid and tenantid
-
contactsPostByTenantid(String tenantId, String region, EntityCreate contact)
→ Future<Entity>
-
Post a new entity to EntitySet Contacts
-
contactsPostByTenantidWithHttpInfo(String tenantId, String region, EntityCreate contact)
→ Future<Response>
-
Post a new entity to EntitySet Contacts
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited