DocumentFilesApi class
Methods
-
documentFilesGetFile(int assetId, int modelId, String fileId, String tenantId, String region)
→ Future<MultipartFile>
-
Downloads binary file related to asset and model
-
documentFilesGetFileWithHttpInfo(int assetId, int modelId, String fileId, String tenantId, String region)
→ Future<Response>
-
Downloads binary file related to asset and model
-
documentFilesUploadSingleFile(String tenantId, String region, MultipartFile file, String documentName, int assetId, int modelId, {String externalId})
→ Future<FileUploadResult>
-
Uploads a document file related to a specific model
-
documentFilesUploadSingleFileWithHttpInfo(String tenantId, String region, MultipartFile file, String documentName, int assetId, int modelId, {String externalId})
→ Future<Response>
-
Uploads a document file related to a specific model
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited