EntityMappingInfo class
Constructors
- EntityMappingInfo({String mappingId, int sourceAssetModelId, int sourceEntityId, int targetAssetModelId, int targetEntityId, EntityBase sourceEntity, EntityBase targetEntity, String matchType, int percentConfidence, ModelMapping mapping})
- Returns a new EntityMappingInfo instance.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- mapping ↔ ModelMapping
-
getter/setter pair
- mappingId ↔ String
-
getter/setter pair
- matchType ↔ String
-
getter/setter pair
- percentConfidence ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceAssetModelId ↔ int
-
getter/setter pair
- sourceEntity ↔ EntityBase
-
getter/setter pair
- sourceEntityId ↔ int
-
getter/setter pair
- targetAssetModelId ↔ int
-
getter/setter pair
- targetEntity ↔ EntityBase
-
getter/setter pair
- targetEntityId ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → EntityMappingInfo -
Returns a new EntityMappingInfo instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< EntityMappingInfo> -
mapFromJson(
dynamic json) → Map< String, EntityMappingInfo> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< EntityMappingInfo> >