FileUploadResult class
Constructors
-
FileUploadResult({List<
String> fileNames = const [], String description, DateTime createdTimestamp, DateTime updatedTimestamp, List<String> contentTypes = const [], List<String> names = const [], List<String> urls = const [], int assetId, List<int> assetModelIds = const []}) - Returns a new FileUploadResult instance.
Properties
- assetId ↔ int
-
getter/setter pair
-
assetModelIds
↔ List<
int> -
getter/setter pair
-
contentTypes
↔ List<
String> -
getter/setter pair
- createdTimestamp ↔ DateTime
-
getter/setter pair
- description ↔ String
-
getter/setter pair
-
fileNames
↔ List<
String> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
-
names
↔ List<
String> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedTimestamp ↔ DateTime
-
getter/setter pair
-
urls
↔ List<
String> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → FileUploadResult -
Returns a new FileUploadResult instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< FileUploadResult> -
mapFromJson(
dynamic json) → Map< String, FileUploadResult> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< FileUploadResult> >