decode method
Decodes a data to a InlineObject1MemberTypeEnum.
If allowNull is true and the data cannot be decoded successfully,
then null is returned. However, if allowNull is false and the data
cannot be decoded successfully, then an UnimplementedError is thrown.
The allowNull is very handy when an API changes and a new enum value is added or removed,
and users are still using an old app with the old code.
Implementation
InlineObject1MemberTypeEnum decode(dynamic data, {bool allowNull}) {
if (data != null) {
switch (data.toString()) {
case r'User': return InlineObject1MemberTypeEnum.user;
case r'Invite': return InlineObject1MemberTypeEnum.invite;
default:
if (allowNull == false) {
throw ArgumentError('Unknown enum value to decode: $data');
}
}
}
return null;
}