logsIngestLogs method
Imports a batch of logs to the central logging service
Summary:Imports a batch of logs to the central logging service.
This service can be used by any client. For XBIM use only.
Return Type:
Parameters:
- String region (required): The data center region the data resides in
Implementation
Future<Object> logsIngestLogs(String region,) async {
final response = await logsIngestLogsWithHttpInfo(region,);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body != null && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'Object',) as Object;
}
return Future<Object>.value();
}