ModelCreate class
Constructors
- ModelCreate({int assetId, @required String name, @required String revision, @required String status, ModelCreateStateEnum state, String segmentName})
- Returns a new ModelCreate instance.
Properties
- assetId ↔ int
-
The Asset Identifier to Associate the model to
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- name ↔ String
-
The name of the model.
getter/setter pair
- revision ↔ String
-
The Revison of the model -e.g. P01
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- segmentName ↔ String
-
An optional SegmentName to associate the model with
getter/setter pair
- state ↔ ModelCreateStateEnum
-
Flag indicating the internal Flex status of the model
getter/setter pair
- status ↔ String
-
The Status/Purpose of the model - e.g S1
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → ModelCreate -
Returns a new ModelCreate instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< ModelCreate> -
mapFromJson(
dynamic json) → Map< String, ModelCreate> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< ModelCreate> >