ModelMappingReport class
Constructors
-
ModelMappingReport({int sourceModelId, int targetModelId, String mappingId, int sourceEntityCount, int targetEntityCount, List<
EntityMappingInfo> mappedEntities = const [], List<EntityMatchInfo> candidateMatches = const [], List<EntityBase> foundEntities = const [], List<EntityBase> lostEntities = const [], List<MappingMessageInfo> messages = const [], int mappedCount, int partialMatchCount, int foundCount, int lostCount, MappingProperties mappingProperties}) - Returns a new ModelMappingReport instance.
Properties
-
candidateMatches
↔ List<
EntityMatchInfo> -
getter/setter pair
- foundCount ↔ int
-
getter/setter pair
-
foundEntities
↔ List<
EntityBase> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- lostCount ↔ int
-
getter/setter pair
-
lostEntities
↔ List<
EntityBase> -
getter/setter pair
- mappedCount ↔ int
-
getter/setter pair
-
mappedEntities
↔ List<
EntityMappingInfo> -
getter/setter pair
- mappingId ↔ String
-
getter/setter pair
- mappingProperties ↔ MappingProperties
-
getter/setter pair
-
messages
↔ List<
MappingMessageInfo> -
getter/setter pair
- partialMatchCount ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceEntityCount ↔ int
-
getter/setter pair
- sourceModelId ↔ int
-
getter/setter pair
- targetEntityCount ↔ int
-
getter/setter pair
- targetModelId ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → ModelMappingReport -
Returns a new ModelMappingReport instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< ModelMappingReport> -
mapFromJson(
dynamic json) → Map< String, ModelMappingReport> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< ModelMappingReport> >