modelsAssignByTenantidAndAssetmodelid method
Future<void>
modelsAssignByTenantidAndAssetmodelid(
- String tenantId,
- int assetModelId,
- String region,
- InlineObject4 parameters,
Assigns a user to the given role on the model
Summary:Assigns a user to the given role on the model.
Return Type:
Parameters:
-
String tenantId (required): The unique Tenant ID (UUID or Identifier string)
-
int assetModelId (required):
-
String region (required): The data center region the data resides in
-
InlineObject4 parameters (required):
Implementation
Future<void> modelsAssignByTenantidAndAssetmodelid(String tenantId, int assetModelId, String region, InlineObject4 parameters,) async {
final response = await modelsAssignByTenantidAndAssetmodelidWithHttpInfo(tenantId, assetModelId, region, parameters,);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
}