modelsPostByTenantid method
Creates a new Model for the given Asset
Summary:Creates a new Model for the given Asset.
The ability to create Models may be limited by access level.
Return Type: Model
Parameters:
-
String tenantId (required): The unique Tenant ID (UUID or Identifier string)
-
String region (required): The data center region the data resides in
-
ModelCreate model (required):
Implementation
Future<Model> modelsPostByTenantid(String tenantId, String region, ModelCreate model,) async {
final response = await modelsPostByTenantidWithHttpInfo(tenantId, region, model,);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body != null && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'Model',) as Model;
}
return Future<Model>.value();
}