modelsRevokeByTenantidAndAssetmodelid method
Future<void>
modelsRevokeByTenantidAndAssetmodelid(
- String tenantId,
- int assetModelId,
- String region,
- InlineObject5 parameters,
Revokes a user from the given role on the model
Summary:Revokes a user from the given role on the model.
Return Type:
Parameters:
-
String tenantId (required): The unique Tenant ID (UUID or Identifier string)
-
int assetModelId (required):
-
String region (required): The data center region the data resides in
-
InlineObject5 parameters (required):
Implementation
Future<void> modelsRevokeByTenantidAndAssetmodelid(String tenantId, int assetModelId, String region, InlineObject5 parameters,) async {
final response = await modelsRevokeByTenantidAndAssetmodelidWithHttpInfo(tenantId, assetModelId, region, parameters,);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
}