ResourcesApi class
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
resourcesAddDocumentByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, DocumentCreate document)
→ Future<Document>
-
Adds a new document to a model entity
-
resourcesAddDocumentByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, DocumentCreate document)
→ Future<Response>
-
Adds a new document to a model entity
-
resourcesAsOfByDateAndTenantid(DateTime date, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<ODataListResponseOfEntity>
-
Get Resources as of by date and tenantid
-
resourcesAsOfByDateAndTenantidWithHttpInfo(DateTime date, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<Response>
-
Get Resources as of by date and tenantid
-
resourcesGetAvailablePropertiesByAssetidAndTenantid(int assetId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<ODataListResponseOfAttributeDefinition>
-
Gets the Properties available on this Model
-
resourcesGetAvailablePropertiesByAssetidAndTenantidWithHttpInfo(int assetId, String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<Response>
-
Gets the Properties available on this Model
-
resourcesGetByTenantid(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<ODataListResponseOfResource>
-
Returns the EntitySet Resources
-
resourcesGetByTenantidWithHttpInfo(String tenantId, String region, {String dollarExpand, String dollarFilter, String dollarSelect, String dollarOrderby, int dollarTop, int dollarSkip, bool dollarCount})
→ Future<Response>
-
Returns the EntitySet Resources
-
resourcesGetSingleEntityByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, {String dollarExpand, String dollarSelect})
→ Future<Resource>
-
Get Resources single entity by assetmodelid, entityid and tenantid
-
resourcesGetSingleEntityByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, {String dollarExpand, String dollarSelect})
→ Future<Response>
-
Get Resources single entity by assetmodelid, entityid and tenantid
-
resourcesPatchByAssetmodelidAndEntityidAndTenantid(int assetModelId, int entityId, String tenantId, String region, EntityEdit patch_)
→ Future<Entity>
-
Patch Resources by assetmodelid, entityid and tenantid
-
resourcesPatchByAssetmodelidAndEntityidAndTenantidWithHttpInfo(int assetModelId, int entityId, String tenantId, String region, EntityEdit patch_)
→ Future<Response>
-
Patch Resources by assetmodelid, entityid and tenantid
-
resourcesPostByTenantid(String tenantId, String region, EntityCreate resource)
→ Future<Entity>
-
Post a new entity to EntitySet Resources
-
resourcesPostByTenantidWithHttpInfo(String tenantId, String region, EntityCreate resource)
→ Future<Response>
-
Post a new entity to EntitySet Resources
-
toString()
→ String
-
A string representation of this object.
inherited