StatsApi class
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
statsMeteredResources(
String tenantId, String region) → Future< Map< String, IMeteredResource> > - Lists the plan allowances and current consumpttion for a tenant's app
-
statsMeteredResourcesWithHttpInfo(
String tenantId, String region) → Future< Response> - Lists the plan allowances and current consumpttion for a tenant's app
-
statsRateLimits(
String tenantId, String region) → Future< Map< String, QuotaStatus> > - Provides details of the permitted rate limits for tenant's app and user
-
statsRateLimitsWithHttpInfo(
String tenantId, String region) → Future< Response> - Provides details of the permitted rate limits for tenant's app and user
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited