UserPermissions class
Constructors
-
UserPermissions({List<
Role> roles = const [], List<Role> parentRoles = const [], List<Role> effectiveRoles = const [], List<UserPermissionsEffectivePermissionsEnum> effectivePermissions = const []}) - Returns a new UserPermissions instance.
Properties
-
effectivePermissions
↔ List<
UserPermissionsEffectivePermissionsEnum> -
getter/setter pair
-
effectiveRoles
↔ List<
Role> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
-
parentRoles
↔ List<
Role> -
getter/setter pair
-
roles
↔ List<
Role> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → UserPermissions -
Returns a new UserPermissions instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< UserPermissions> -
mapFromJson(
dynamic json) → Map< String, UserPermissions> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< UserPermissions> >