ValueContainer class
Constructors
-
ValueContainer({List<
ValueContainerDataTypeFlagsEnum> dataTypeFlags = const [], ValueContainerDataTypeEnum dataType, String text, bool logical, DateTime date, int integer, double real}) - Returns a new ValueContainer instance.
Properties
- dataType ↔ ValueContainerDataTypeEnum
-
getter/setter pair
-
dataTypeFlags
↔ List<
ValueContainerDataTypeFlagsEnum> -
getter/setter pair
- date ↔ DateTime
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- integer ↔ int
-
getter/setter pair
- logical ↔ bool
-
getter/setter pair
- real ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → ValueContainer -
Returns a new ValueContainer instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → List< ValueContainer> -
mapFromJson(
dynamic json) → Map< String, ValueContainer> -
mapListFromJson(
dynamic json, {bool emptyIsNull, bool growable}) → Map< String, List< ValueContainer> >