WexbimApi class
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
wexbimGetComplete(int assetId, int modelId, String tenantId, String region)
→ Future<MultipartFile>
-
Gets the pre-generated complete wexbim geometry stream for a model
-
wexbimGetCompleteWithHttpInfo(int assetId, int modelId, String tenantId, String region)
→ Future<Response>
-
Gets the pre-generated complete wexbim geometry stream for a model
-
wexbimGetComponents(int assetId, int modelId, String tenantId, String region)
→ Future<MultipartFile>
-
Gets the pre-generated components wexbim geometry stream for a model
-
wexbimGetComponentsWithHttpInfo(int assetId, int modelId, String tenantId, String region)
→ Future<Response>
-
Gets the pre-generated components wexbim geometry stream for a model
-
wexbimGetDynamic(int assetId, int modelId, List<String> included, String tenantId, String region, {List<String> excluded})
→ Future<MultipartFile>
-
Gets a dynamically generated geometry stream for a model
-
wexbimGetDynamicWithHttpInfo(int assetId, int modelId, List<String> included, String tenantId, String region, {List<String> excluded})
→ Future<Response>
-
Gets a dynamically generated geometry stream for a model
-
wexbimGetEnvelope(int assetId, int modelId, String tenantId, String region)
→ Future<MultipartFile>
-
Gets the pre-generated building envelope wexbim geometry stream for a model
-
wexbimGetEnvelopeCut(int assetId, int modelId, double bottom, double top, String tenantId, String region)
→ Future<MultipartFile>
-
Gets the building envelope geometry cut plane. This can be used to cap the holes after clipping.
-
wexbimGetEnvelopeCutWithHttpInfo(int assetId, int modelId, double bottom, double top, String tenantId, String region)
→ Future<Response>
-
Gets the building envelope geometry cut plane. This can be used to cap the holes after clipping.
-
wexbimGetEnvelopeFreeCut(int assetId, int modelId, List<double> planes, String tenantId, String region)
→ Future<MultipartFile>
-
Gets the a cutplane across the envelope for up to 6 cut planes.
-
wexbimGetEnvelopeFreeCutWithHttpInfo(int assetId, int modelId, List<double> planes, String tenantId, String region)
→ Future<Response>
-
Gets the a cutplane across the envelope for up to 6 cut planes.
-
wexbimGetEnvelopeWithHttpInfo(int assetId, int modelId, String tenantId, String region)
→ Future<Response>
-
Gets the pre-generated building envelope wexbim geometry stream for a model
-
wexbimGetSite(int assetId, int modelId, String tenantId, String region)
→ Future<MultipartFile>
-
Gets the pre-generated Site wexbim geometry stream for a model
-
wexbimGetSiteWithHttpInfo(int assetId, int modelId, String tenantId, String region)
→ Future<Response>
-
Gets the pre-generated Site wexbim geometry stream for a model
-
wexbimGetSpatialStructure(int assetId, int modelId, String tenantId, String region)
→ Future<MultipartFile>
-
Gets the pre-generated spatial wexbim geometry stream for a model
-
wexbimGetSpatialStructureWithHttpInfo(int assetId, int modelId, String tenantId, String region)
→ Future<Response>
-
Gets the pre-generated spatial wexbim geometry stream for a model
-
wexbimGetWindowsAndDoors(int assetId, int modelId, String tenantId, String region)
→ Future<MultipartFile>
-
Gets the pre-generated doors/windows wexbim geometry stream for a model
-
wexbimGetWindowsAndDoorsWithHttpInfo(int assetId, int modelId, String tenantId, String region)
→ Future<Response>
-
Gets the pre-generated doors/windows wexbim geometry stream for a model