wexbimGetEnvelopeCut method
Gets the building envelope geometry cut plane. This can be used to cap the holes after clipping.
Summary:Gets the building envelope geometry cut plane. This can be used to cap the holes after clipping..
Return Type: string
Parameters:
Implementation
Future<MultipartFile> wexbimGetEnvelopeCut(int assetId, int modelId, double bottom, double top, String tenantId, String region,) async {
final response = await wexbimGetEnvelopeCutWithHttpInfo(assetId, modelId, bottom, top, tenantId, region,);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body != null && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'MultipartFile',) as MultipartFile;
}
return Future<MultipartFile>.value();
}