wexbimGetEnvelopeCutWithHttpInfo method
Gets the building envelope geometry cut plane. This can be used to cap the holes after clipping.
Summary:Gets the building envelope geometry cut plane. This can be used to cap the holes after clipping..
Return Type: string
Note: This method returns the HTTP Response.
Parameters:
Implementation
Future<Response> wexbimGetEnvelopeCutWithHttpInfo(int assetId, int modelId, double bottom, double top, String tenantId, String region,) async {
// Verify required params are set.
if (assetId == null) {
throw ApiException(HttpStatus.badRequest, 'Missing required param: assetId');
}
if (modelId == null) {
throw ApiException(HttpStatus.badRequest, 'Missing required param: modelId');
}
if (bottom == null) {
throw ApiException(HttpStatus.badRequest, 'Missing required param: bottom');
}
if (top == null) {
throw ApiException(HttpStatus.badRequest, 'Missing required param: top');
}
if (tenantId == null) {
throw ApiException(HttpStatus.badRequest, 'Missing required param: tenantId');
}
if (region == null) {
throw ApiException(HttpStatus.badRequest, 'Missing required param: region');
}
// ignore: prefer_const_declarations
final path = r'/{region}/aim/2.0/{tenantId}/wexbim/envelopecut'
.replaceAll('{tenantId}', tenantId)
.replaceAll('{region}', region);
// ignore: prefer_final_locals
Object postBody;
final queryParams = <QueryParam>[];
final headerParams = <String, String>{};
final formParams = <String, String>{};
queryParams.addAll(_convertParametersForCollectionFormat('', 'assetId', assetId));
queryParams.addAll(_convertParametersForCollectionFormat('', 'modelId', modelId));
queryParams.addAll(_convertParametersForCollectionFormat('', 'bottom', bottom));
queryParams.addAll(_convertParametersForCollectionFormat('', 'top', top));
const authNames = <String>['oauth2'];
const contentTypes = <String>[];
return apiClient.invokeAPI(
path,
'GET',
queryParams,
postBody,
headerParams,
formParams,
contentTypes.isEmpty ? null : contentTypes[0],
authNames,
);
}